import { CommonModule } from '@angular/common';
import { Directive, Component, ViewEncapsulation, ChangeDetectionStrategy, Input, ContentChild, TemplateRef, ViewChild, Attribute, Renderer2, ContentChildren, ElementRef, Pipe, NgModule } from '@angular/core';
import { coerceBooleanProperty } from '@angular/cdk/coercion';
import { Md5 } from 'ts-md5/dist/md5';

const PALETTE_SIZE = 16;
class UxgImageAvatar {
}
UxgImageAvatar.decorators = [
    { type: Directive, args: [{
                selector: 'uxg-image-avatar, [uxg-image-avatar], [uxgImageAvatar]'
            },] }
];
class AvatarComponent {
    constructor() {
        this.color = 'gradient';
        this._dense = false;
        this.avatarImage = null;
    }
    get dense() {
        return this._dense;
    }
    set dense(value) {
        this._dense = coerceBooleanProperty(value);
    }
    getCode(str) {
        const charCodes = str
            .split('')
            .map((char) => char.charCodeAt(0))
            .join('');
        return parseInt(charCodes, 10);
    }
    generateGravatar() {
        const rand = Math.random()
            .toString(36)
            .replace(/[^a-z]+/g, '')
            .substr(0, 5);
        const gravatarHash = this.gravatarEmail ? Md5.hashStr(this.gravatarEmail) : Md5.hashStr(rand);
        this.gravatarUrl = `//gravatar.com/avatar/${gravatarHash}?s=512`;
        if (this.defaultGravatar && !this.gravatarEmail) {
            this.gravatarUrl = `${this.gravatarUrl}&default=${this.defaultGravatar}`;
        }
    }
    ngOnInit() {
        if (this.name && this.color === 'initials') {
            this.paletteColor = (this.getCode(this.name) % PALETTE_SIZE) + 1;
        }
        if (this.gravatarEmail || this.defaultGravatar) {
            this.generateGravatar();
        }
        this.avatarContent = this._explicitContent || this.avatarImage || this._implicitContent;
    }
}
AvatarComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-avatar',
                template: "<div\n  class=\"uxg-avatar\"\n  [class.uxg-primary-color]=\"color === 'primary'\"\n  [class.uxg-accent-color]=\"color === 'accent'\"\n  [ngClass]=\"color === 'initials' ? 'uxg-avatar-color-' + paletteColor : ''\"\n  [class.uxg-gravatar]=\"gravatarEmail || defaultGravatar\"\n>\n  <ng-container *ngTemplateOutlet=\"avatarContent\"></ng-container>\n</div>\n\n<ng-template #implicitContent>\n  <img *ngIf=\"gravatarEmail || defaultGravatar; else nameAvatar\" [src]=\"gravatarUrl\" />\n  <ng-template #nameAvatar>\n    <ng-container *ngIf=\"name\">\n      {{ name | initials: dense }}\n    </ng-container>\n  </ng-template>\n</ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [".uxg-avatar-color-1{background:rgba(var(--color-primary),1)}.uxg-avatar-color-2{background:#4538cb}.uxg-avatar-color-3{background:#2123c0}.uxg-avatar-color-4{background:#141483}.uxg-avatar-color-5{background:rgba(var(--color-primary-darker),1)}.uxg-avatar-color-6{background:rgba(var(--color-secondary),1)}.uxg-avatar-color-7{background:#ac258d}.uxg-avatar-color-8{background:#9d1880}.uxg-avatar-color-9{background:#910d75}.uxg-avatar-color-10{background:rgba(var(--color-secondary-darker),1)}.uxg-avatar-color-11{background:rgba(var(--color-warn),1)}.uxg-avatar-color-12{background:rgba(var(--color-warn-darker),1)}.uxg-avatar-color-13{background:#56c271}.uxg-avatar-color-14{background:#3c874e}.uxg-avatar-color-15{background:#ff8a3d}.uxg-avatar-color-16{background:#b2602a}.uxg-avatar-color-17{background:#f0b323}.uxg-avatar-color-18{background:#a87d18}.uxg-avatar-color-19{background:#5bc1d7}.uxg-avatar-color-20{background:#3f8696}.uxg-avatar-color-21{background:#d2d755}.uxg-avatar-color-22{background:#92963b}"]
            },] }
];
/** @nocollapse */
AvatarComponent.ctorParameters = () => [];
AvatarComponent.propDecorators = {
    name: [{ type: Input }],
    gravatarEmail: [{ type: Input }],
    defaultGravatar: [{ type: Input }],
    color: [{ type: Input }],
    dense: [{ type: Input }],
    avatarImage: [{ type: Input }],
    _explicitContent: [{ type: ContentChild, args: [UxgImageAvatar, { read: TemplateRef, static: true },] }],
    _implicitContent: [{ type: ViewChild, args: ['implicitContent', { static: true },] }]
};

class AvatarListComponent {
    constructor(dense, large, renderer) {
        this.dense = dense;
        this.large = large;
        this.renderer = renderer;
    }
    ngAfterContentInit() {
        this.avatars.forEach((avatar, i) => {
            this.renderer.setStyle(avatar.nativeElement, 'z-index', this.avatars.length - i);
        });
        if (this.totalLength) {
            this.extra = this.totalLength - this.avatars.length;
        }
    }
}
AvatarListComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-avatar-list',
                template: "<ul class=\"uxg-avatar-list\" [attr.dense]=\"dense === '' || null\" [attr.large]=\"large === '' || null\">\n  <ng-content select=\"uxg-avatar\"></ng-content>\n  <li class=\"uxg-avatar-number\">+{{ extra }}</li>\n</ul>\n"
            },] }
];
/** @nocollapse */
AvatarListComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Attribute, args: ['dense',] }] },
    { type: undefined, decorators: [{ type: Attribute, args: ['large',] }] },
    { type: Renderer2 }
];
AvatarListComponent.propDecorators = {
    totalLength: [{ type: Input }],
    avatars: [{ type: ContentChildren, args: [AvatarComponent, { read: ElementRef },] }]
};

class InitialsPipe {
    transform(fullName, dense) {
        const [name, surname] = fullName.split(' ');
        let initials = name.charAt(0).toUpperCase();
        if (!dense) {
            if (surname) {
                initials += surname.charAt(0).toUpperCase();
            }
            else if (name.length >= 2) {
                initials += name.charAt(1).toUpperCase();
            }
        }
        return initials;
    }
}
InitialsPipe.decorators = [
    { type: Pipe, args: [{
                name: 'initials'
            },] }
];

class AvatarModule {
}
AvatarModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [AvatarComponent, AvatarListComponent, UxgImageAvatar, InitialsPipe],
                exports: [AvatarComponent, AvatarListComponent, UxgImageAvatar, InitialsPipe]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { AvatarComponent, AvatarListComponent, AvatarModule, InitialsPipe, UxgImageAvatar };
//# sourceMappingURL=ffdc-uxg-angular-components-avatar.js.map
