import { Component, ViewEncapsulation, ChangeDetectionStrategy, Input, NgModule } from '@angular/core';
import { coerceBooleanProperty } from '@angular/cdk/coercion';
import { MatTooltipModule } from '@angular/material/tooltip';
import { CommonModule } from '@angular/common';

class BannerComponent {
    constructor() {
        this._bannerData = [];
        this._small = false;
        //prevent ui update to avoid tooltip doesn't work due to tooltip fresh
        this.trackByFn = (index, item) => item.name;
    }
    set bannerData(data) {
        if (data && data.length > 0) {
            this._bannerData = data;
        }
    }
    get banners() {
        return this._bannerData.map((banner) => {
            return {
                name: banner.name,
                text: this.getBannerText(banner),
                tooltip: banner.tooltip
            };
        });
    }
    get small() {
        return this._small;
    }
    set small(value) {
        this._small = coerceBooleanProperty(value);
    }
    abbreviateNumber(number) {
        const SI_SYMBOL = ['', 'k', 'M', 'G', 'T', 'P', 'E'];
        // what tier? (determines SI symbol)
        // tslint:disable-next-line: no-bitwise
        const tier = (Math.log10(number) / 3) | 0;
        // if zero, we don't need a suffix
        if (tier === 0)
            return number;
        // get suffix and determine scale
        const suffix = SI_SYMBOL[tier];
        const scale = Math.pow(10, tier * 3);
        // scale the number
        const scaled = number / scale;
        // format number and add suffix
        return scaled.toFixed(1) + suffix;
    }
    getBannerText(banner) {
        if (typeof banner.value === 'number') {
            let bannerText = '';
            if (banner.prefix) {
                bannerText += banner.prefix + ' ';
            }
            bannerText += this.abbreviateNumber(banner.value).toString();
            if (banner.suffix) {
                bannerText += ' ' + banner.suffix;
            }
            return bannerText;
        }
        return banner.value;
    }
}
BannerComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-banner',
                template: "<ng-container *ngFor=\"let bannerItem of banners; last as islast; trackBy: trackByFn\">\n  <div class=\"uxg-banner-item\">\n    <span\n      [ngClass]=\"{ 'uxg-display-3': !small, 'uxg-banner-item--smal-label': small }\"\n      matTooltip=\"{{ bannerItem.tooltip }}\"\n      #tooltip=\"matTooltip\"\n      >{{ bannerItem.text }}</span\n    >\n    <span>{{ bannerItem.name }}</span>\n  </div>\n  <div class=\"uxg-banner-spliter\"></div>\n</ng-container>\n",
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.Default,
                host: {
                    class: 'uxg-banner',
                    '[class.uxg-banner-small]': 'small'
                },
                styles: [".mt-0{margin-top:0!important}.pt-0{padding-top:0!important}.mb-0{margin-bottom:0!important}.pb-0{padding-bottom:0!important}.ml-0{margin-left:0!important}.pl-0{padding-left:0!important}.mr-0{margin-right:0!important}.pr-0{padding-right:0!important}.m-0{margin:0!important}.p-0{padding:0!important}.mt-1{margin-top:4px!important}.pt-1{padding-top:4px!important}.mb-1{margin-bottom:4px!important}.pb-1{padding-bottom:4px!important}.ml-1{margin-left:4px!important}.pl-1{padding-left:4px!important}.mr-1{margin-right:4px!important}.pr-1{padding-right:4px!important}.m-1{margin:4px!important}.p-1{padding:4px!important}.mt-2{margin-top:8px!important}.pt-2{padding-top:8px!important}.mb-2{margin-bottom:8px!important}.pb-2{padding-bottom:8px!important}.ml-2{margin-left:8px!important}.pl-2{padding-left:8px!important}.mr-2{margin-right:8px!important}.pr-2{padding-right:8px!important}.m-2{margin:8px!important}.p-2{padding:8px!important}.mt-3{margin-top:16px!important}.pt-3{padding-top:16px!important}.mb-3{margin-bottom:16px!important}.pb-3{padding-bottom:16px!important}.ml-3{margin-left:16px!important}.pl-3{padding-left:16px!important}.mr-3{margin-right:16px!important}.pr-3{padding-right:16px!important}.m-3{margin:16px!important}.p-3{padding:16px!important}.mt-4{margin-top:24px!important}.pt-4{padding-top:24px!important}.mb-4{margin-bottom:24px!important}.pb-4{padding-bottom:24px!important}.ml-4{margin-left:24px!important}.pl-4{padding-left:24px!important}.mr-4{margin-right:24px!important}.pr-4{padding-right:24px!important}.m-4{margin:24px!important}.p-4{padding:24px!important}.mt-5{margin-top:48px!important}.pt-5{padding-top:48px!important}.mb-5{margin-bottom:48px!important}.pb-5{padding-bottom:48px!important}.ml-5{margin-left:48px!important}.pl-5{padding-left:48px!important}.mr-5{margin-right:48px!important}.pr-5{padding-right:48px!important}.m-5{margin:48px!important}.p-5{padding:48px!important}.mt-6{margin-top:96px!important}.pt-6{padding-top:96px!important}.mb-6{margin-bottom:96px!important}.pb-6{padding-bottom:96px!important}.ml-6{margin-left:96px!important}.pl-6{padding-left:96px!important}.mr-6{margin-right:96px!important}.pr-6{padding-right:96px!important}.m-6{margin:96px!important}.p-6{padding:96px!important}.uxg-banner{margin:8px;display:flex;flex-direction:row;align-items:stretch}.uxg-banner .uxg-banner-spliter{display:block;border-right-width:1px;border-right-style:solid;margin-top:16px;margin-bottom:16px}.uxg-banner .uxg-banner-item{min-width:120px;width:100%;display:flex;flex-direction:column;align-items:center;margin:8px}.uxg-banner.uxg-banner-small .uxg-banner-spliter{margin-top:0;margin-bottom:0}.uxg-banner .uxg-banner-spliter:last-of-type{display:none}"]
            },] }
];
BannerComponent.propDecorators = {
    bannerData: [{ type: Input }],
    small: [{ type: Input }]
};

class BannerModule {
}
BannerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [BannerComponent],
                imports: [MatTooltipModule, CommonModule],
                exports: [BannerComponent]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { BannerComponent, BannerModule };
//# sourceMappingURL=ffdc-uxg-angular-components-banner.js.map
