import { EventEmitter, Directive, ElementRef, Output, HostListener, NgModule, ɵɵdefineInjectable, ɵɵinject, Injectable, Inject } from '@angular/core';
import { DOCUMENT } from '@angular/common';
import { from, BehaviorSubject } from 'rxjs';
import { share } from 'rxjs/operators';
import mapValues from 'lodash/mapValues';

class ClickOutsideDirective {
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.uxgClickOutside = new EventEmitter();
    }
    onClick(target) {
        const clickedInside = this.elementRef.nativeElement.contains(target);
        if (!clickedInside) {
            this.uxgClickOutside.emit();
        }
    }
}
ClickOutsideDirective.decorators = [
    { type: Directive, args: [{
                selector: '[uxgClickOutside]'
            },] }
];
/** @nocollapse */
ClickOutsideDirective.ctorParameters = () => [
    { type: ElementRef }
];
ClickOutsideDirective.propDecorators = {
    uxgClickOutside: [{ type: Output }],
    onClick: [{ type: HostListener, args: ['document:click', ['$event.target'],] }]
};

class ClickOutsideModule {
}
ClickOutsideModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ClickOutsideDirective],
                exports: [ClickOutsideDirective]
            },] }
];

class LazyloadScriptService {
    constructor(document) {
        this.document = document;
        this._loadedScripts = new Map();
    }
    load(scriptPath, moduleId) {
        if (!this._loadedScripts.has(scriptPath)) {
            this._loadedScripts.set(scriptPath, from(this._load(scriptPath, moduleId)).pipe(share()));
        }
        return this._loadedScripts.get(scriptPath);
    }
    _load(scriptPath, moduleId) {
        const script = document.createElement('script');
        script.type = 'text/javascript';
        script.src = scriptPath;
        script.onerror = () => console.error(`Error loading ${moduleId} from ${scriptPath}`);
        this.document.body.appendChild(script);
        return new Promise((resolve, reject) => {
            let counter = 200; // equivalent of 10 seconds...
            const fn = () => {
                const loadedModule = window[moduleId];
                if (loadedModule) {
                    resolve(loadedModule);
                }
                else if (counter > 0) {
                    counter--;
                    setTimeout(fn, 50);
                }
                else {
                    reject(new Error(`Error loading ${moduleId} library from ${scriptPath}. Timeout.`));
                }
            };
            fn();
        });
    }
}
/** @nocollapse */ LazyloadScriptService.ɵprov = ɵɵdefineInjectable({ factory: function LazyloadScriptService_Factory() { return new LazyloadScriptService(ɵɵinject(DOCUMENT)); }, token: LazyloadScriptService, providedIn: "root" });
LazyloadScriptService.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */
LazyloadScriptService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];

const PALETTE_DEFAULT_CONFIG = {
    colorWay: ['#694ED6', '#C137A2', '#E40046', '#56C271', '#FF8A3D', '#D2D755', '#F0B323', '#5BC1D7'],
    colorScale: [
        // reversed due to a plotly bug
        [0, 'rgb(73, 54, 150)'],
        [0.1, 'rgb(73, 54, 150)'],
        [0.3, 'rgb(105, 78, 214)'],
        [0.5, 'rgb(143, 123, 225)'],
        [0.6, 'rgb(180, 166, 234)'],
        [0.7, 'rgb(217, 211, 245)'],
        [1, 'rgb(206, 206, 206)']
    ],
    vectorMap: {
        marker: {
            line: {
                color: '#fff',
                width: 0.5
            }
        }
    }
};

const PALETTE_CONFIG = 'PALETTE_CONFIG';

class PaletteService {
    constructor(config) {
        this.config = config;
        this.internalSubject = new BehaviorSubject(this.config);
        this.paletteChange$ = this.internalSubject.asObservable();
    }
    ngOnDestroy() {
        this.internalSubject.complete();
    }
    changePalette(newPaletteConfig) {
        this.config = newPaletteConfig;
        this.internalSubject.next(this.config);
    }
}
PaletteService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
PaletteService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [PALETTE_CONFIG,] }] }
];

const ɵ0 = PALETTE_DEFAULT_CONFIG;
class PaletteModule {
}
PaletteModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    PaletteService,
                    {
                        provide: PALETTE_CONFIG,
                        useValue: ɵ0
                    }
                ]
            },] }
];

// created from https://github.com/lodash/lodash/issues/3298#issuecomment-341685354
function createChain(chainableFunctions) {
    return function (input) {
        let value = input;
        const wrapper = Object.assign(Object.assign({}, mapValues(chainableFunctions, (f) => (...args) => {
            // lodash always puts input as the first argument
            value = f(value, ...args);
            return wrapper;
        })), { value: () => value });
        return wrapper;
    };
}

/**
 * Generated bundle index. Do not edit.
 */

export { ClickOutsideModule, LazyloadScriptService, PALETTE_CONFIG, PALETTE_DEFAULT_CONFIG, PaletteModule, PaletteService, createChain, ɵ0, ClickOutsideDirective as ɵa };
//# sourceMappingURL=ffdc-uxg-angular-components-core.js.map
