import { EventEmitter, Component, ViewEncapsulation, Input, Output, NgModule } from '@angular/core';
import { MatButtonModule } from '@angular/material/button';
import { MatIconModule } from '@angular/material/icon';
import { MatCardModule } from '@angular/material/card';
import { MatMenuModule } from '@angular/material/menu';
import { CommonModule } from '@angular/common';

class EntityMenuComponent {
    constructor() {
        this.items = [];
        this.data = [];
        this.title = '';
        this.abbreviationLength = 3;
        this.itemClick = new EventEmitter();
    }
    ngOnInit() { }
    ngOnChanges(changes) {
        if (changes.data || changes.property) {
            this.items = this.mapData(this.data.slice(0, 9), this.property);
        }
    }
    onItemClick(value, $event) {
        this.itemClick.emit({
            value,
            $event
        });
    }
    mapData(data, property) {
        return data.map((item) => {
            const value = property ? item[property] : item;
            return {
                name: value,
                abbr: this.formatItemName(value),
                value: item
            };
        });
    }
    formatItemName(name) {
        if (name) {
            return name
                .split(' ')
                .map((str) => str.charAt(0))
                .join('')
                .toUpperCase()
                .substring(0, this.abbreviationLength);
        }
        return name;
    }
}
EntityMenuComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-entity-menu',
                template: "<button mat-icon-button [matMenuTriggerFor]=\"menu\" ng-init color=\"primary\">\n  <mat-icon>apps</mat-icon>\n</button>\n\n<mat-menu #menu=\"matMenu\" class=\"container-list\">\n  <h6 class=\"uxg-h6 solutions-title\">{{ title || 'Title' }}</h6>\n  <div class=\"solution-list\">\n    <div\n      *ngFor=\"let item of items\"\n      class=\"solution-item\"\n      (click)=\"onItemClick(item.value, $event)\"\n      (auxclick)=\"onItemClick(item.value, $event)\"\n      [title]=\"item.name\"\n    >\n      <mat-card class=\"uxg-card-solution container-list-item\" extra-dense>\n        <span class=\"uxg-h5 uxg-card-solution-name\">\n          {{ item.abbr || 'SN' }}\n        </span>\n      </mat-card>\n      <h5 class=\"uxg-subtitle-4 solution-name\">{{ item.name || 'Solution Name' }}</h5>\n    </div>\n  </div>\n  <ng-content select=\"uxg-entity-menu-actions\"></ng-content>\n</mat-menu>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".mt-0{margin-top:0!important}.pt-0{padding-top:0!important}.mb-0{margin-bottom:0!important}.pb-0{padding-bottom:0!important}.ml-0{margin-left:0!important}.pl-0{padding-left:0!important}.mr-0{margin-right:0!important}.pr-0{padding-right:0!important}.m-0{margin:0!important}.p-0{padding:0!important}.mt-1{margin-top:4px!important}.pt-1{padding-top:4px!important}.mb-1{margin-bottom:4px!important}.pb-1{padding-bottom:4px!important}.ml-1{margin-left:4px!important}.pl-1{padding-left:4px!important}.mr-1{margin-right:4px!important}.pr-1{padding-right:4px!important}.m-1{margin:4px!important}.p-1{padding:4px!important}.mt-2{margin-top:8px!important}.pt-2{padding-top:8px!important}.mb-2{margin-bottom:8px!important}.pb-2{padding-bottom:8px!important}.ml-2{margin-left:8px!important}.pl-2{padding-left:8px!important}.mr-2{margin-right:8px!important}.pr-2{padding-right:8px!important}.m-2{margin:8px!important}.p-2{padding:8px!important}.mt-3{margin-top:16px!important}.pt-3{padding-top:16px!important}.mb-3{margin-bottom:16px!important}.pb-3{padding-bottom:16px!important}.ml-3{margin-left:16px!important}.pl-3{padding-left:16px!important}.mr-3{margin-right:16px!important}.pr-3{padding-right:16px!important}.m-3{margin:16px!important}.p-3{padding:16px!important}.mt-4{margin-top:24px!important}.pt-4{padding-top:24px!important}.mb-4{margin-bottom:24px!important}.pb-4{padding-bottom:24px!important}.ml-4{margin-left:24px!important}.pl-4{padding-left:24px!important}.mr-4{margin-right:24px!important}.pr-4{padding-right:24px!important}.m-4{margin:24px!important}.p-4{padding:24px!important}.mt-5{margin-top:48px!important}.pt-5{padding-top:48px!important}.mb-5{margin-bottom:48px!important}.pb-5{padding-bottom:48px!important}.ml-5{margin-left:48px!important}.pl-5{padding-left:48px!important}.mr-5{margin-right:48px!important}.pr-5{padding-right:48px!important}.m-5{margin:48px!important}.p-5{padding:48px!important}.mt-6{margin-top:96px!important}.pt-6{padding-top:96px!important}.mb-6{margin-bottom:96px!important}.pb-6{padding-bottom:96px!important}.ml-6{margin-left:96px!important}.pl-6{padding-left:96px!important}.mr-6{margin-right:96px!important}.pr-6{padding-right:96px!important}.m-6{margin:96px!important}.p-6{padding:96px!important}.container-list{max-width:427px!important}.container-list .mat-menu-content:not(:empty){padding:0}.container-list .mat-menu-content{margin:24px}.container-list .mat-menu-content .solutions-title{margin-bottom:32px}.container-list .mat-menu-content .solution-list{display:grid;grid-template-columns:1fr 1fr 1fr;grid-gap:16px}.container-list .mat-menu-content .solution-list .solution-item{display:flex;flex-direction:column;align-items:center;justify-content:center;margin-bottom:24px;cursor:pointer}.container-list .mat-menu-content .solution-list .solution-item .solution-name{text-align:center;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;width:100px;margin:8px 0}"]
            },] }
];
EntityMenuComponent.propDecorators = {
    data: [{ type: Input }],
    title: [{ type: Input }],
    property: [{ type: Input }],
    abbreviationLength: [{ type: Input }],
    itemClick: [{ type: Output }]
};
class EntityMenuActionsComponent {
}
EntityMenuActionsComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-entity-menu-actions',
                template: ` <ng-content></ng-content> `
            },] }
];

const components = [EntityMenuComponent, EntityMenuActionsComponent];
class EntityMenuModule {
}
EntityMenuModule.decorators = [
    { type: NgModule, args: [{
                declarations: [...components],
                imports: [CommonModule, MatButtonModule, MatIconModule, MatCardModule, MatMenuModule],
                exports: [...components]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { EntityMenuActionsComponent, EntityMenuComponent, EntityMenuModule };
//# sourceMappingURL=ffdc-uxg-angular-components-entity-menu.js.map
