import { CommonModule } from '@angular/common';
import { Component, Inject, Directive, ElementRef, Input, EventEmitter, ViewEncapsulation, ChangeDetectionStrategy, ChangeDetectorRef, Output, ContentChildren, ViewChild, NgModule } from '@angular/core';
import { FlexLayoutModule } from '@angular/flex-layout';
import { FormControl, Validators, ReactiveFormsModule, FormsModule } from '@angular/forms';
import { MatExpansionPanel, MatExpansionModule } from '@angular/material/expansion';
import { MatIconModule } from '@angular/material/icon';
import { MatButtonModule } from '@angular/material/button';
import { MatDividerModule } from '@angular/material/divider';
import { MatBadgeModule } from '@angular/material/badge';
import { MatChipsModule } from '@angular/material/chips';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatInputModule } from '@angular/material/input';
import { MatDialogRef, MAT_DIALOG_DATA, MatDialogConfig, MatDialog, MatDialogModule } from '@angular/material/dialog';
import { ClickOutsideModule } from '@ffdc/uxg-angular-components/core';

class FilterGroupDialogComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    onNoClick() {
        this.dialogRef.close();
    }
    save() {
        if (!this.filterName.invalid)
            this.dialogRef.close(this.filterName.value);
    }
    ngOnInit() {
        this.filterName = new FormControl('', [Validators.required, this.nameExistsValidator()]);
    }
    nameExistsValidator() {
        return (control) => {
            return this.data.existingNames.indexOf(control.value) >= 0 ? { nameExists: { value: control.value } } : null;
        };
    }
    getErrorMessage() {
        return this.filterName.hasError('required')
            ? 'Name is required'
            : this.filterName.hasError('nameExists')
                ? 'Name already exists'
                : '';
    }
}
FilterGroupDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-filter-group-dialog',
                template: "<div mat-dialog-content class=\"filter-group-dialog-header\">\n  <div class=\"dialog-title uxg-h6\">Name of Filter</div>\n</div>\n<div mat-dialog-content>\n  <mat-form-field class=\"filter-group-dialog-form\">\n    <input matInput placeholder=\"Name\" maxlength=\"10\" [formControl]=\"filterName\" />\n    <mat-error *ngIf=\"filterName.invalid\">{{ getErrorMessage() }}</mat-error>\n  </mat-form-field>\n</div>\n<div mat-dialog-actions class=\"filter-group-dialog-actions\">\n  <button mat-stroked-button color=\"accent\" (click)=\"save()\">Save</button>\n</div>\n",
                styles: [".mt-0{margin-top:0!important}.pt-0{padding-top:0!important}.mb-0{margin-bottom:0!important}.pb-0{padding-bottom:0!important}.ml-0{margin-left:0!important}.pl-0{padding-left:0!important}.mr-0{margin-right:0!important}.pr-0{padding-right:0!important}.m-0{margin:0!important}.p-0{padding:0!important}.mt-1{margin-top:4px!important}.pt-1{padding-top:4px!important}.mb-1{margin-bottom:4px!important}.pb-1{padding-bottom:4px!important}.ml-1{margin-left:4px!important}.pl-1{padding-left:4px!important}.mr-1{margin-right:4px!important}.pr-1{padding-right:4px!important}.m-1{margin:4px!important}.p-1{padding:4px!important}.mt-2{margin-top:8px!important}.pt-2{padding-top:8px!important}.mb-2{margin-bottom:8px!important}.pb-2{padding-bottom:8px!important}.ml-2{margin-left:8px!important}.pl-2{padding-left:8px!important}.mr-2{margin-right:8px!important}.pr-2{padding-right:8px!important}.m-2{margin:8px!important}.p-2{padding:8px!important}.mt-3{margin-top:16px!important}.pt-3{padding-top:16px!important}.mb-3{margin-bottom:16px!important}.pb-3{padding-bottom:16px!important}.ml-3{margin-left:16px!important}.pl-3{padding-left:16px!important}.mr-3{margin-right:16px!important}.pr-3{padding-right:16px!important}.m-3{margin:16px!important}.p-3{padding:16px!important}.mt-4{margin-top:24px!important}.pt-4{padding-top:24px!important}.mb-4{margin-bottom:24px!important}.pb-4{padding-bottom:24px!important}.ml-4{margin-left:24px!important}.pl-4{padding-left:24px!important}.mr-4{margin-right:24px!important}.pr-4{padding-right:24px!important}.m-4{margin:24px!important}.p-4{padding:24px!important}.mt-5{margin-top:48px!important}.pt-5{padding-top:48px!important}.mb-5{margin-bottom:48px!important}.pb-5{padding-bottom:48px!important}.ml-5{margin-left:48px!important}.pl-5{padding-left:48px!important}.mr-5{margin-right:48px!important}.pr-5{padding-right:48px!important}.m-5{margin:48px!important}.p-5{padding:48px!important}.mt-6{margin-top:96px!important}.pt-6{padding-top:96px!important}.mb-6{margin-bottom:96px!important}.pb-6{padding-bottom:96px!important}.ml-6{margin-left:96px!important}.pl-6{padding-left:96px!important}.mr-6{margin-right:96px!important}.pr-6{padding-right:96px!important}.m-6{margin:96px!important}.p-6{padding:96px!important}.filter-group-dialog-header{position:relative;top:-24px}.filter-group-dialog-header .dialog-title{margin-top:16px}.filter-group-dialog-form{width:100%}.filter-group-dialog-actions.mat-dialog-actions{display:flex;justify-content:center}"]
            },] }
];
/** @nocollapse */
FilterGroupDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];

class UxgFilter {
    constructor(ref) {
        this.ref = ref;
        this.instance = '';
    }
    ngAfterViewInit() {
        this.component = this.ref.nativeElement.__component;
    }
}
UxgFilter.decorators = [
    { type: Directive, args: [{ selector: '[uxgFilter]' },] }
];
/** @nocollapse */
UxgFilter.ctorParameters = () => [
    { type: ElementRef }
];
UxgFilter.propDecorators = {
    instance: [{ type: Input, args: ['uxgFilter',] }]
};

class FilterGroupComponent {
    constructor(dialog, cd) {
        this.dialog = dialog;
        this.cd = cd;
        this.changes = new EventEmitter();
        this.expanded = false;
        this.divideAtIndex = [];
        this.showActions = false;
        this.autoApply = false;
        this.subscriptions = [];
        this.selectedData = [];
        this.savedFilters = [];
        this.existingFilterNames = [];
        this.initialState = [];
        this.activeFilter = [];
        this.isActive = false;
        this.headerHeight = '40px';
    }
    ngAfterViewInit() {
        this.filterInstances.forEach((filterInstance) => {
            const instanceTitle = filterInstance.instance;
            const selected = {};
            selected[instanceTitle] = filterInstance.component.getState();
            this.selectedData.push({ title: instanceTitle, selectedData: [...selected[instanceTitle]] });
            this.initialState.push({ title: instanceTitle, selectedData: [...selected[instanceTitle]] });
            this.subscriptions.push(filterInstance.component.changes.subscribe((change) => {
                change.instance = instanceTitle;
                this.selectedData.forEach((filter) => {
                    if (filter.title === change.instance) {
                        filter.selectedData = filterInstance.component.getState();
                    }
                });
                this.changes.emit(change);
                if (this.autoApply) {
                    this.applyFilters();
                }
            }));
        });
        setTimeout(() => this.applyFilters());
    }
    ngOnDestroy() {
        this.subscriptions.forEach((s) => s.unsubscribe());
    }
    openDialog() {
        const dialogConfig = new MatDialogConfig();
        dialogConfig.width = '300px';
        dialogConfig.data = {
            existingNames: this.existingFilterNames
        };
        this.dialogRef = this.dialog.open(FilterGroupDialogComponent, dialogConfig);
        const state = this.getFilterStates();
        this.dialogRef.afterClosed().subscribe((result) => {
            if (result) {
                this.savedFilters.forEach((filter) => {
                    filter.isSelected = false;
                });
                this.existingFilterNames.push(result.trim());
                this.savedFilters.push({
                    filterName: result.trim(),
                    filterState: state,
                    isSelected: true
                });
            }
            this.dialogRef = undefined;
            this.cd.markForCheck();
        });
    }
    selectFilter(filter) {
        this.savedFilters.forEach((savedFilter) => {
            if (savedFilter.filterName === filter.filterName) {
                savedFilter.isSelected = true;
            }
            else {
                savedFilter.isSelected = false;
            }
        });
        this.setState(filter.filterState);
    }
    applyFilters() {
        let change;
        const activeFilter = [];
        this.filterInstances.forEach((filterInstance) => {
            const data = filterInstance.component.getState();
            activeFilter.push({ title: filterInstance.instance, selectedData: data });
            change = {
                instance: filterInstance.instance,
                added: data,
                removed: []
            };
            this.changes.emit(change);
        });
        this.activeFilter = activeFilter;
        this.isActive = this.checkIsActive();
    }
    updateFilter() {
        const state = this.getFilterStates();
        this.savedFilters.forEach((filter) => {
            if (filter.isSelected) {
                filter.filterState = state;
            }
        });
    }
    removeFilter(filter) {
        this.savedFilters = this.savedFilters.filter((item) => item !== filter);
        this.existingFilterNames = this.existingFilterNames.filter((items) => items !== filter.filterName);
    }
    clearSelection() {
        this.filterInstances.forEach((filterInstance) => {
            filterInstance.component.clearSelection();
        });
        this.selectedData.forEach((instance) => {
            instance.selectedData.length = 0;
        });
    }
    resetSelection() {
        this.setState(this.initialState);
    }
    getFilterStates() {
        const groupState = [];
        this.filterInstances.forEach((instance) => {
            if (instance.component.getState) {
                groupState.push({
                    title: instance.instance,
                    selectedData: instance.component.getState()
                });
            }
        });
        return groupState;
    }
    getState() {
        return [...this.selectedData];
    }
    setState(data) {
        if (data.length) {
            this.filterInstances.forEach((filterInstance) => {
                for (let i = 0; i < data.length; i++) {
                    if (filterInstance.instance === data[i].title && filterInstance.component.setState) {
                        filterInstance.component.setState(data[i].selectedData);
                    }
                }
            });
            data.forEach((obj) => {
                this.selectedData.forEach((obj2) => {
                    if (obj.title === obj2.title) {
                        obj2.selectedData.length = 0;
                        obj2.selectedData.push(...obj.selectedData);
                    }
                });
            });
        }
    }
    open() {
        if (this.activeFilter.length) {
            this.setState(this.activeFilter);
            if (this.savedFilters.length) {
                for (let i = 0; i < this.savedFilters.length; i++)
                    if (this.savedFilters[i].isSelected === true &&
                        !this.checkListEquality(this.savedFilters[i].filterState, this.activeFilter)) {
                        this.savedFilters[i].isSelected = false;
                        break;
                    }
            }
        }
        else if (this.savedFilters.length) {
            this.setState(this.getSelectedFilterState());
        }
    }
    close() {
        if (this.activeFilter.length) {
            this.setState(this.activeFilter);
        }
        else if (this.savedFilters.length) {
            this.setState(this.getSelectedFilterState());
        }
        else {
            this.resetSelection();
        }
    }
    getSelectedFilterState() {
        const stateArray = [];
        this.savedFilters.forEach((filter) => {
            if (filter.isSelected) {
                for (const key in filter.filterState) {
                    if (filter.filterState.hasOwnProperty(key))
                        stateArray.push(filter.filterState[key]);
                }
            }
        });
        return stateArray;
    }
    checkIsActive() {
        if (this.selectedData.some((data) => data.selectedData.length) &&
            this.activeFilter.some((data) => data.selectedData.length)) {
            return this.checkListEquality(this.activeFilter, this.selectedData);
        }
        return false;
    }
    checkListEquality(listA, listB) {
        for (let i = 0; i < listA.length; i++) {
            if (listA[i].title === listB[i].title && listA[i].selectedData.length === listB[i].selectedData.length) {
                for (let j = 0; j < listA[i].selectedData.length; j++) {
                    if (listB[i].selectedData.indexOf(listA[i].selectedData[j]) === -1) {
                        return false;
                    }
                }
            }
            else {
                return false;
            }
        }
        return true;
    }
    checkDivider(index) {
        if (this.divideAtIndex.indexOf(index) >= 0) {
            return true;
        }
        else {
            return false;
        }
    }
    handleOutsideClick() {
        if (this.expansionPanel.expanded && !this.dialogRef) {
            this.expansionPanel.close();
        }
    }
}
FilterGroupComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-filter-group',
                template: "<mat-expansion-panel\n  #filterGroupPanel\n  class=\"uxg-expansion-filter uxg-filter-group\"\n  hideToggle=\"true\"\n  [expanded]=\"expanded\"\n  [class.active]=\"isActive\"\n  (uxgClickOutside)=\"handleOutsideClick()\"\n>\n  <mat-expansion-panel-header\n    [expandedHeight]=\"headerHeight\"\n    [collapsedHeight]=\"headerHeight\"\n    (click)=\"$event.stopPropagation(); filterGroupPanel.expanded ? open() : close()\"\n  >\n    <div class=\"uxg-filter-group-header\">\n      <div class=\"selectedFilters\">\n        <ng-container *ngFor=\"let filter of selectedData; let i = index\">\n          <div\n            *ngIf=\"filter.selectedData.length && !filter.selectedData[0].value\"\n            matBadge=\"{{ filter.selectedData.length }}\"\n            class=\"uxg-group-filter uxg-side-badge\"\n          >\n            {{ filter.title }}\n          </div>\n          <div *ngIf=\"!filter.selectedData.length\" matBadge=\"All\" class=\"uxg-group-filter uxg-side-badge\">\n            {{ filter.title }}\n          </div>\n          <div\n            *ngIf=\"filter.selectedData.length && filter.selectedData[0].value\"\n            class=\"uxg-group-filter uxg-side-badge\"\n          >\n            {{ filter.title }}<span class=\"filter-value\">{{ filter.selectedData[0].label }}</span>\n          </div>\n          <mat-divider *ngIf=\"checkDivider(i)\" class=\"filter-divider\" vertical></mat-divider>\n        </ng-container>\n      </div>\n      <span class=\"fill-remaining-space\"></span>\n      <div class=\"expand-button\">\n        <button mat-icon-button [color]=\"filterGroupPanel.expanded ? 'primary' : 'neutral'\">\n          <mat-icon>{{ filterGroupPanel.expanded ? 'arrow_drop_up' : 'arrow_drop_down' }}</mat-icon>\n        </button>\n      </div>\n    </div>\n  </mat-expansion-panel-header>\n\n  <div class=\"expansion-panel-header\">\n    <h6 class=\"uxg-h6\">Filter by</h6>\n    <button mat-button color=\"accent\" dense (click)=\"clearSelection()\">\n      <mat-icon>refresh</mat-icon>\n      Reset\n    </button>\n  </div>\n\n  <ng-template matExpansionPanelContent>\n    <div class=\"expansion-panel-content\" fxLayout=\"row wrap\" fxLayoutAlign=\"start\">\n      <ng-content></ng-content>\n    </div>\n\n    <ng-container *ngIf=\"showActions\">\n      <mat-divider></mat-divider>\n      <div class=\"expansion-panel-actions\" fxLayout=\"row wrap\">\n        <div class=\"saved-filters-container\">\n          <mat-chip-list #savedFiltersList>\n            <mat-chip\n              *ngFor=\"let filter of savedFilters\"\n              large\n              removable\n              (click)=\"selectFilter(filter)\"\n              [selected]=\"filter.isSelected\"\n              (removed)=\"removeFilter(filter)\"\n            >\n              {{ filter.filterName }}\n              <mat-icon matChipRemove>cancel</mat-icon>\n            </mat-chip>\n          </mat-chip-list>\n        </div>\n\n        <button *ngIf=\"savedFilters.length\" mat-button color=\"accent\" (click)=\"updateFilter()\">Update</button>\n        <button *ngIf=\"savedFilters.length\" mat-button color=\"accent\" (click)=\"clearSelection()\">Clear</button>\n        <mat-divider vertical=\"true\"></mat-divider>\n        <button mat-stroked-button color=\"accent\" (click)=\"openDialog()\">Save as</button>\n        <button mat-stroked-button color=\"accent\" (click)=\"filterGroupPanel.toggle(); close()\">Cancel</button>\n        <button mat-flat-button color=\"accent\" (click)=\"applyFilters()\">Apply</button>\n      </div>\n    </ng-container>\n  </ng-template>\n</mat-expansion-panel>\n",
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [".mt-0{margin-top:0!important}.pt-0{padding-top:0!important}.mb-0{margin-bottom:0!important}.pb-0{padding-bottom:0!important}.ml-0{margin-left:0!important}.pl-0{padding-left:0!important}.mr-0{margin-right:0!important}.pr-0{padding-right:0!important}.m-0{margin:0!important}.p-0{padding:0!important}.mt-1{margin-top:4px!important}.pt-1{padding-top:4px!important}.mb-1{margin-bottom:4px!important}.pb-1{padding-bottom:4px!important}.ml-1{margin-left:4px!important}.pl-1{padding-left:4px!important}.mr-1{margin-right:4px!important}.pr-1{padding-right:4px!important}.m-1{margin:4px!important}.p-1{padding:4px!important}.mt-2{margin-top:8px!important}.pt-2{padding-top:8px!important}.mb-2{margin-bottom:8px!important}.pb-2{padding-bottom:8px!important}.ml-2{margin-left:8px!important}.pl-2{padding-left:8px!important}.mr-2{margin-right:8px!important}.pr-2{padding-right:8px!important}.m-2{margin:8px!important}.p-2{padding:8px!important}.mt-3{margin-top:16px!important}.pt-3{padding-top:16px!important}.mb-3{margin-bottom:16px!important}.pb-3{padding-bottom:16px!important}.ml-3{margin-left:16px!important}.pl-3{padding-left:16px!important}.mr-3{margin-right:16px!important}.pr-3{padding-right:16px!important}.m-3{margin:16px!important}.p-3{padding:16px!important}.mt-4{margin-top:24px!important}.pt-4{padding-top:24px!important}.mb-4{margin-bottom:24px!important}.pb-4{padding-bottom:24px!important}.ml-4{margin-left:24px!important}.pl-4{padding-left:24px!important}.mr-4{margin-right:24px!important}.pr-4{padding-right:24px!important}.m-4{margin:24px!important}.p-4{padding:24px!important}.mt-5{margin-top:48px!important}.pt-5{padding-top:48px!important}.mb-5{margin-bottom:48px!important}.pb-5{padding-bottom:48px!important}.ml-5{margin-left:48px!important}.pl-5{padding-left:48px!important}.mr-5{margin-right:48px!important}.pr-5{padding-right:48px!important}.m-5{margin:48px!important}.p-5{padding:48px!important}.mt-6{margin-top:96px!important}.pt-6{padding-top:96px!important}.mb-6{margin-bottom:96px!important}.pb-6{padding-bottom:96px!important}.ml-6{margin-left:96px!important}.pl-6{padding-left:96px!important}.mr-6{margin-right:96px!important}.pr-6{padding-right:96px!important}.m-6{margin:96px!important}.p-6{padding:96px!important}.uxg-expansion-filter .filter-value{padding:0 8px}.uxg-expansion-filter .mat-expansion-panel-header{border-width:1px;border-style:solid;cursor:default!important;padding-right:0}.uxg-expansion-filter .mat-expansion-panel-header .uxg-filter-group-header{width:100%;display:flex;align-items:center;cursor:default}.uxg-expansion-filter .mat-expansion-panel-header .uxg-filter-group-header .fill-remaining-space{flex:1 1 auto}.uxg-expansion-filter .mat-expansion-panel-header .uxg-filter-group-header .selectedFilters{overflow:hidden;display:flex}.uxg-expansion-filter .mat-expansion-panel-header .uxg-filter-group-header .selectedFilters .uxg-group-filter{flex:0 0 auto;margin-right:24px}.uxg-expansion-filter .mat-expansion-panel-header .uxg-filter-group-header .selectedFilters .filter-divider{margin-right:24px}.uxg-expansion-filter .mat-expansion-panel-header .uxg-filter-group-header .selectedFilters .mat-standard-chip{cursor:pointer}.expansion-panel-header{display:flex;padding:8px 24px;box-sizing:border-box;justify-content:space-between;border-top-left-radius:4px;border-top-right-radius:4px}.expansion-panel-header .uxg-h6{align-self:center;margin-bottom:0}.expansion-panel-content{padding:24px}.expansion-panel-actions{padding:16px;align-items:center}.expansion-panel-actions .saved-filters-container{flex:1}.expansion-panel-actions .saved-filters-container .mat-chip{cursor:pointer}.expansion-panel-actions .mat-button-base{margin-left:16px}"]
            },] }
];
/** @nocollapse */
FilterGroupComponent.ctorParameters = () => [
    { type: MatDialog },
    { type: ChangeDetectorRef }
];
FilterGroupComponent.propDecorators = {
    changes: [{ type: Output }],
    filterInstances: [{ type: ContentChildren, args: [UxgFilter, { descendants: true },] }],
    expansionPanel: [{ type: ViewChild, args: [MatExpansionPanel,] }],
    expanded: [{ type: Input }],
    divideAtIndex: [{ type: Input }],
    showActions: [{ type: Input }],
    autoApply: [{ type: Input }]
};

class FilterGroupModule {
}
FilterGroupModule.decorators = [
    { type: NgModule, args: [{
                declarations: [FilterGroupComponent, UxgFilter, FilterGroupDialogComponent],
                imports: [
                    ReactiveFormsModule,
                    CommonModule,
                    MatExpansionModule,
                    MatIconModule,
                    MatButtonModule,
                    MatDividerModule,
                    MatBadgeModule,
                    MatChipsModule,
                    MatFormFieldModule,
                    MatInputModule,
                    FlexLayoutModule,
                    MatDialogModule,
                    FormsModule,
                    ClickOutsideModule
                ],
                entryComponents: [FilterGroupDialogComponent],
                exports: [FilterGroupComponent, UxgFilter]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { FilterGroupComponent, FilterGroupModule, UxgFilter as ɵa, FilterGroupDialogComponent as ɵb };
//# sourceMappingURL=ffdc-uxg-angular-components-filter-filter-group.js.map
