import { EventEmitter, Component, ViewEncapsulation, ElementRef, Input, Output, ViewChild, Pipe, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { MatAutocomplete, MatAutocompleteTrigger, MatAutocompleteModule } from '@angular/material/autocomplete';
import { MatChipsModule } from '@angular/material/chips';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatIconModule } from '@angular/material/icon';
import { MatInputModule } from '@angular/material/input';
import { FormControl, ReactiveFormsModule } from '@angular/forms';
import { ENTER, COMMA } from '@angular/cdk/keycodes';
import { startWith, map } from 'rxjs/operators';

class FilterTagsComponent {
    constructor(hostElement) {
        this.hostElement = hostElement;
        this.visible = true;
        this.removable = true;
        this.addOnBlur = true;
        this.separatorKeysCodes = [ENTER, COMMA];
        this.toHighlight = '';
        this.formCtrl = new FormControl();
        this.selectedData = [];
        this._data = [];
        this.placeholder = 'Filter by tags';
        this.ariaLabel = 'Input Tag';
        this.changes = new EventEmitter();
        this.hostElement.nativeElement.__component = this;
        this.data = [];
    }
    set data(data) {
        this._data = data;
        this.selectedData = this.data.filter((tag) => tag.isSelected);
    }
    get data() {
        return this._data;
    }
    ngOnInit() {
        this.filteredTags$ = this.formCtrl.valueChanges.pipe(startWith(null), map((tag) => {
            if (tag) {
                return this.filter(tag);
            }
            else {
                this.toHighlight = '';
                return this.data.slice();
            }
        }));
    }
    add(event) {
        if (!this.autocomplete.isOpen) {
            const input = event.input;
            const value = (event.value || '').trim();
            const validValue = this.data.some((el) => el.label === value);
            if (validValue) {
                this.selectedData.push({ label: value });
            }
            if (input) {
                input.value = '';
            }
            this.formCtrl.setValue(null);
            if (value) {
                this.changes.emit({ added: [{ label: event.value }], removed: [] });
            }
        }
    }
    remove(tag) {
        this.trigger.closePanel();
        const index = this.selectedData.indexOf(tag);
        if (index >= 0) {
            const tagAtIndex = this.selectedData.splice(index, 1);
            this.changes.emit({ added: [], removed: [...tagAtIndex] });
        }
        this.toHighlight = '';
    }
    onSelected(event) {
        if (this.selectedData.indexOf(event.option.value) === -1) {
            this.selectedData.push(event.option.value);
            this.changes.emit({ added: [event.option.value], removed: [] });
        }
        this.toHighlight = '';
        this.input.nativeElement.value = '';
        this.formCtrl.setValue(null);
    }
    clearSelection() {
        if (!this.selectedData.length) {
            return;
        }
        const removed = [...this.selectedData];
        this.selectedData.length = 0;
        this.changes.emit({ added: [], removed });
        this.toHighlight = '';
    }
    onClick() {
        this.trigger._onChange('');
        this.trigger.openPanel();
    }
    applyHighlight(tag) {
        const element = this.selectedData.find((el) => el.label === tag.label);
        if (element) {
            return true;
        }
        return false;
    }
    isTag(value) {
        return value.label !== undefined;
    }
    filter(value) {
        let filterValue;
        if (this.isTag(value)) {
            filterValue = value.label.toLowerCase();
        }
        else {
            filterValue = value.toLowerCase();
        }
        this.toHighlight = filterValue;
        return this.data.filter((tag) => tag.label.toLowerCase().includes(filterValue));
    }
    getState() {
        return [...this.selectedData];
    }
    setState(data) {
        this.selectedData = [...data];
    }
}
FilterTagsComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-filter-tags',
                template: "<div class=\"filter-tags-container\">\n  <mat-chip-list #chipList aria-label=\"Tags selection\">\n    <mat-chip dense selected *ngFor=\"let tag of selectedData\" [removable]=\"removable\" (removed)=\"remove(tag)\">\n      {{ tag.label }}\n      <mat-icon matChipRemove *ngIf=\"removable\">cancel</mat-icon>\n    </mat-chip>\n  </mat-chip-list>\n\n  <mat-form-field class=\"chip-list\" appearance=\"fill\" dense>\n    <mat-icon matPrefix dense class=\"search-icon\">search</mat-icon>\n    <input\n      [attr.aria-label]=\"ariaLabel\"\n      matInput\n      type=\"text\"\n      #tagInput\n      [placeholder]=\"placeholder\"\n      [formControl]=\"formCtrl\"\n      [matAutocomplete]=\"autocomplete\"\n      [matChipInputFor]=\"chipList\"\n      [matChipInputSeparatorKeyCodes]=\"separatorKeysCodes\"\n      [matChipInputAddOnBlur]=\"addOnBlur\"\n      (matChipInputTokenEnd)=\"add($event)\"\n      (click)=\"onClick()\"\n    />\n  </mat-form-field>\n  <mat-autocomplete #autocomplete (optionSelected)=\"onSelected($event)\">\n    <mat-option\n      *ngFor=\"let tag of filteredTags$ | async\"\n      [value]=\"tag\"\n      [ngClass]=\"{\n        'selected-option-highlight': applyHighlight(tag)\n      }\"\n      (click)=\"$event.stopPropagation()\"\n    >\n      <span [innerHTML]=\"tag.label | highlight: toHighlight\"></span>\n    </mat-option>\n  </mat-autocomplete>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".mt-0{margin-top:0!important}.pt-0{padding-top:0!important}.mb-0{margin-bottom:0!important}.pb-0{padding-bottom:0!important}.ml-0{margin-left:0!important}.pl-0{padding-left:0!important}.mr-0{margin-right:0!important}.pr-0{padding-right:0!important}.m-0{margin:0!important}.p-0{padding:0!important}.mt-1{margin-top:4px!important}.pt-1{padding-top:4px!important}.mb-1{margin-bottom:4px!important}.pb-1{padding-bottom:4px!important}.ml-1{margin-left:4px!important}.pl-1{padding-left:4px!important}.mr-1{margin-right:4px!important}.pr-1{padding-right:4px!important}.m-1{margin:4px!important}.p-1{padding:4px!important}.mt-2{margin-top:8px!important}.pt-2{padding-top:8px!important}.mb-2{margin-bottom:8px!important}.pb-2{padding-bottom:8px!important}.ml-2{margin-left:8px!important}.pl-2{padding-left:8px!important}.mr-2{margin-right:8px!important}.pr-2{padding-right:8px!important}.m-2{margin:8px!important}.p-2{padding:8px!important}.mt-3{margin-top:16px!important}.pt-3{padding-top:16px!important}.mb-3{margin-bottom:16px!important}.pb-3{padding-bottom:16px!important}.ml-3{margin-left:16px!important}.pl-3{padding-left:16px!important}.mr-3{margin-right:16px!important}.pr-3{padding-right:16px!important}.m-3{margin:16px!important}.p-3{padding:16px!important}.mt-4{margin-top:24px!important}.pt-4{padding-top:24px!important}.mb-4{margin-bottom:24px!important}.pb-4{padding-bottom:24px!important}.ml-4{margin-left:24px!important}.pl-4{padding-left:24px!important}.mr-4{margin-right:24px!important}.pr-4{padding-right:24px!important}.m-4{margin:24px!important}.p-4{padding:24px!important}.mt-5{margin-top:48px!important}.pt-5{padding-top:48px!important}.mb-5{margin-bottom:48px!important}.pb-5{padding-bottom:48px!important}.ml-5{margin-left:48px!important}.pl-5{padding-left:48px!important}.mr-5{margin-right:48px!important}.pr-5{padding-right:48px!important}.m-5{margin:48px!important}.p-5{padding:48px!important}.mt-6{margin-top:96px!important}.pt-6{padding-top:96px!important}.mb-6{margin-bottom:96px!important}.pb-6{padding-bottom:96px!important}.ml-6{margin-left:96px!important}.pl-6{padding-left:96px!important}.mr-6{margin-right:96px!important}.pr-6{padding-right:96px!important}.m-6{margin:96px!important}.p-6{padding:96px!important}uxg-filter-tags .filter-tags-container .chip-list{width:100%;margin-top:8px}uxg-filter-tags .filter-tags-container .chip-list input.mat-chip-input{margin:inherit;flex:none}"]
            },] }
];
/** @nocollapse */
FilterTagsComponent.ctorParameters = () => [
    { type: ElementRef }
];
FilterTagsComponent.propDecorators = {
    data: [{ type: Input }],
    placeholder: [{ type: Input }],
    ariaLabel: [{ type: Input }],
    changes: [{ type: Output }],
    input: [{ type: ViewChild, args: ['tagInput', { static: true },] }],
    autocomplete: [{ type: ViewChild, args: [MatAutocomplete, { static: true },] }],
    trigger: [{ type: ViewChild, args: [MatAutocompleteTrigger, { static: true },] }]
};

class HighlightPipe {
    transform(text, search) {
        const pattern = search
            .replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g, '\\$&')
            .split(' ')
            .filter((t) => t.length > 0)
            .join('|');
        const regex = new RegExp(pattern, 'gi');
        if (!text.match(regex)) {
            return text;
        }
        return search ? text.replace(regex, (match) => `<span class="search-term-highlight">${match}</span>`) : text;
    }
}
HighlightPipe.decorators = [
    { type: Pipe, args: [{ name: 'highlight' },] }
];

class FilterTagsModule {
}
FilterTagsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [FilterTagsComponent, HighlightPipe],
                imports: [
                    ReactiveFormsModule,
                    CommonModule,
                    MatIconModule,
                    MatChipsModule,
                    MatAutocompleteModule,
                    MatFormFieldModule,
                    MatInputModule
                ],
                exports: [FilterTagsComponent, HighlightPipe]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { FilterTagsComponent, FilterTagsModule, HighlightPipe };
//# sourceMappingURL=ffdc-uxg-angular-components-filter-filter-tags.js.map
