import { CommonModule } from '@angular/common';
import { EventEmitter, Component, ElementRef, Input, Output, NgModule } from '@angular/core';
import { ReactiveFormsModule } from '@angular/forms';
import { MatButtonToggleModule } from '@angular/material/button-toggle';
import { MatIconModule } from '@angular/material/icon';

class FilterToggleComponent {
    constructor(hostElement) {
        this.hostElement = hostElement;
        this._data = [];
        this.showIcon = true;
        this.showLabel = true;
        this.dense = false;
        this.uxgClass = '';
        this.changes = new EventEmitter();
        this.hostElement.nativeElement.__component = this;
    }
    set data(data) {
        this._data = data;
    }
    get data() {
        return this._data;
    }
    ngOnInit() {
        this.data.forEach((toggleBtn) => {
            if (toggleBtn.isSelected) {
                this.initialValue = toggleBtn;
                this.selectedValue = toggleBtn;
                this.previousValue = toggleBtn;
            }
        });
    }
    onValueChange(val) {
        this.selectedValue = val;
        this.changes.emit({ added: [val], removed: [this.previousValue] });
        this.previousValue = val;
    }
    clearSelection() {
        this.selectedValue = undefined;
        this.changes.emit({ added: [], removed: [this.previousValue] });
    }
    reset() {
        if (this.initialValue) {
            this.selectedValue = this.initialValue;
            this.changes.emit({ added: [this.initialValue], removed: [this.previousValue] });
        }
    }
    getState() {
        return this.selectedValue ? [this.selectedValue] : [];
    }
    setState(value) {
        if (value.length) {
            this.selectedValue = value[0];
        }
    }
}
FilterToggleComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-filter-toggle',
                template: "<mat-button-toggle-group\n  #group=\"matButtonToggleGroup\"\n  [value]=\"selectedValue\"\n  (change)=\"onValueChange(group.value)\"\n  [attr.dense]=\"dense || null\"\n  [ngClass]=\"uxgClass\"\n>\n  <ng-container *ngFor=\"let item of data\">\n    <mat-button-toggle [value]=\"item\">\n      <ng-container *ngIf=\"item.matIcon && showIcon\">\n        <mat-icon fontSet=\"material-icons-outlined\">{{ item.matIcon }}</mat-icon>\n      </ng-container>\n\n      <span *ngIf=\"showLabel\">{{ item.label }}</span>\n    </mat-button-toggle>\n  </ng-container>\n</mat-button-toggle-group>\n",
                styles: [":host,:host .mat-button-toggle-group{width:100%}"]
            },] }
];
/** @nocollapse */
FilterToggleComponent.ctorParameters = () => [
    { type: ElementRef }
];
FilterToggleComponent.propDecorators = {
    data: [{ type: Input }],
    showIcon: [{ type: Input }],
    showLabel: [{ type: Input }],
    dense: [{ type: Input }],
    uxgClass: [{ type: Input }],
    changes: [{ type: Output }]
};

class FilterToggleModule {
}
FilterToggleModule.decorators = [
    { type: NgModule, args: [{
                declarations: [FilterToggleComponent],
                imports: [ReactiveFormsModule, CommonModule, MatButtonToggleModule, MatIconModule],
                exports: [FilterToggleComponent]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { FilterToggleComponent, FilterToggleModule };
//# sourceMappingURL=ffdc-uxg-angular-components-filter-filter-toggle.js.map
