import { EventEmitter, Component, ElementRef, Input, Output, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { MatChipsModule } from '@angular/material/chips';
import { MatIconModule } from '@angular/material/icon';
import { ReactiveFormsModule } from '@angular/forms';
import cloneDeep from 'lodash/cloneDeep';

class MultiselectTagsComponent {
    constructor(hostElement) {
        this.hostElement = hostElement;
        this._data = [];
        this.dense = null;
        this.large = null;
        this.changes = new EventEmitter();
        this.hostElement.nativeElement.__component = this;
        this.data = [];
    }
    set data(data) {
        this._data = cloneDeep(data);
    }
    get data() {
        return this._data;
    }
    onTagSelection(tag) {
        if (tag.isSelected) {
            this.remove(tag);
        }
        else {
            this.add(tag);
        }
        this.removeFocusFromChip();
    }
    removeFocusFromChip() {
        const tmpElem = document.createElement('input');
        document.body.appendChild(tmpElem);
        tmpElem.focus();
        document.body.removeChild(tmpElem);
    }
    add(tag) {
        const index = this.data.indexOf(tag);
        if (index >= 0) {
            this.data[index].isSelected = true;
            this.changes.emit({ added: [this.data[index]], removed: [] });
        }
    }
    remove(tag) {
        const index = this.data.indexOf(tag);
        if (index >= 0) {
            this.data[index].isSelected = false;
            this.changes.emit({ added: [], removed: [this.data[index]] });
        }
    }
    clearSelection() {
        if (!this.data.some((tag) => tag.isSelected)) {
            return;
        }
        this.changes.emit({ added: [], removed: [...this.data] });
        this.data.forEach((tag) => (tag.isSelected = false));
    }
    getState() {
        const filteredMultiTags = this.data.filter((el) => el.isSelected === true);
        return [...filteredMultiTags];
    }
    setState(data) {
        this.data.forEach((tag) => {
            let found = false;
            data.forEach((el) => {
                if (el.label === tag.label) {
                    tag.isSelected = true;
                    found = true;
                }
            });
            if (!found) {
                delete tag.isSelected;
            }
        });
    }
}
MultiselectTagsComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-multiselect-tags',
                template: "<div class=\"multiselect-tags-container\">\n  <mat-chip-list #chipList aria-label=\"Multi tags selection\" multiple=\"true\">\n    <mat-chip\n      [attr.dense]=\"dense\"\n      [attr.large]=\"large\"\n      *ngFor=\"let tag of data\"\n      [selected]=\"tag.isSelected\"\n      (click)=\"onTagSelection(tag)\"\n    >\n      <mat-icon *ngIf=\"tag.isSelected\" matChipAvatar>check</mat-icon>\n      {{ tag.label }}\n    </mat-chip>\n  </mat-chip-list>\n</div>\n",
                styles: [".chip-list{width:100%}mat-chip{cursor:pointer}"]
            },] }
];
/** @nocollapse */
MultiselectTagsComponent.ctorParameters = () => [
    { type: ElementRef }
];
MultiselectTagsComponent.propDecorators = {
    dense: [{ type: Input, args: ['dense',] }],
    large: [{ type: Input, args: ['large',] }],
    data: [{ type: Input }],
    changes: [{ type: Output }]
};

class MultiselectTagsModule {
}
MultiselectTagsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MultiselectTagsComponent],
                imports: [ReactiveFormsModule, CommonModule, MatIconModule, MatChipsModule],
                exports: [MultiselectTagsComponent]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { MultiselectTagsComponent, MultiselectTagsModule };
//# sourceMappingURL=ffdc-uxg-angular-components-filter-multiselect-tags.js.map
