import { EventEmitter, Component, Input, Output, Inject, forwardRef, ChangeDetectorRef, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { NavigationEnd, Router } from '@angular/router';
import { filter } from 'rxjs/operators';
import { ReplaySubject } from 'rxjs';
import { MatSidenav, MatSidenavModule } from '@angular/material/sidenav';
import { MatToolbarModule } from '@angular/material/toolbar';
import { MatButtonModule } from '@angular/material/button';
import { MatIconModule } from '@angular/material/icon';
import { MatCardModule } from '@angular/material/card';
import { MatListModule } from '@angular/material/list';
import { UxgBreadcrumbModule } from '@ffdc/uxg-angular-components/breadcrumb';

class GlobalNavComponent {
    constructor(router) {
        this.router = router;
        this.menuClick = new EventEmitter();
        this.brandAction = new EventEmitter();
        this.nodeChosen = new EventEmitter();
        this.logout = new EventEmitter();
        this.currentRoute = new ReplaySubject();
        this.router.events.pipe(filter((event) => event instanceof NavigationEnd)).subscribe((currentRoute) => {
            const route = currentRoute.url;
            this.currentRoute.next(route);
        });
    }
    ngOnInit() {
        if (!this.currentNode) {
            this.currentRoute.subscribe((currentRoute) => {
                const currentNode = this.navigationNodes.find((node) => node.path === currentRoute.replace(/\//g, ''));
                if (currentNode) {
                    this.currentNode = currentNode;
                    this.activeRoute = currentRoute;
                }
            });
        }
    }
    ngOnDestroy() { }
}
GlobalNavComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-global-nav',
                template: "<mat-sidenav-container class=\"uxg-nav\">\n  <mat-sidenav #globalNavDrawer mode=\"over\">\n    <uxg-sidenav\n      [appName]=\"appName\"\n      [navigationNodes]=\"navigationNodes\"\n      [activeRoute]=\"activeRoute\"\n      (nodeChosen)=\"nodeChosen.emit($event)\"\n      (logout)=\"logout.emit()\"\n    ></uxg-sidenav>\n  </mat-sidenav>\n\n  <mat-sidenav-content>\n    <uxg-navbar\n      [appName]=\"appName\"\n      [currentNode]=\"currentNode\"\n      [navbarAction]=\"navbarAction\"\n      (menuClick)=\"globalNavDrawer.toggle()\"\n      (nodeChosen)=\"nodeChosen.emit($event)\"\n      (brandAction)=\"brandAction.emit($event)\"\n    >\n    </uxg-navbar>\n\n    <div class=\"app-content\">\n      <ng-container *ngTemplateOutlet=\"appContent\"></ng-container>\n    </div>\n  </mat-sidenav-content>\n</mat-sidenav-container>\n",
                host: {
                    class: 'uxg-global-nav'
                },
                styles: [".mt-0{margin-top:0!important}.pt-0{padding-top:0!important}.mb-0{margin-bottom:0!important}.pb-0{padding-bottom:0!important}.ml-0{margin-left:0!important}.pl-0{padding-left:0!important}.mr-0{margin-right:0!important}.pr-0{padding-right:0!important}.m-0{margin:0!important}.p-0{padding:0!important}.mt-1{margin-top:4px!important}.pt-1{padding-top:4px!important}.mb-1{margin-bottom:4px!important}.pb-1{padding-bottom:4px!important}.ml-1{margin-left:4px!important}.pl-1{padding-left:4px!important}.mr-1{margin-right:4px!important}.pr-1{padding-right:4px!important}.m-1{margin:4px!important}.p-1{padding:4px!important}.mt-2{margin-top:8px!important}.pt-2{padding-top:8px!important}.mb-2{margin-bottom:8px!important}.pb-2{padding-bottom:8px!important}.ml-2{margin-left:8px!important}.pl-2{padding-left:8px!important}.mr-2{margin-right:8px!important}.pr-2{padding-right:8px!important}.m-2{margin:8px!important}.p-2{padding:8px!important}.mt-3{margin-top:16px!important}.pt-3{padding-top:16px!important}.mb-3{margin-bottom:16px!important}.pb-3{padding-bottom:16px!important}.ml-3{margin-left:16px!important}.pl-3{padding-left:16px!important}.mr-3{margin-right:16px!important}.pr-3{padding-right:16px!important}.m-3{margin:16px!important}.p-3{padding:16px!important}.mt-4{margin-top:24px!important}.pt-4{padding-top:24px!important}.mb-4{margin-bottom:24px!important}.pb-4{padding-bottom:24px!important}.ml-4{margin-left:24px!important}.pl-4{padding-left:24px!important}.mr-4{margin-right:24px!important}.pr-4{padding-right:24px!important}.m-4{margin:24px!important}.p-4{padding:24px!important}.mt-5{margin-top:48px!important}.pt-5{padding-top:48px!important}.mb-5{margin-bottom:48px!important}.pb-5{padding-bottom:48px!important}.ml-5{margin-left:48px!important}.pl-5{padding-left:48px!important}.mr-5{margin-right:48px!important}.pr-5{padding-right:48px!important}.m-5{margin:48px!important}.p-5{padding:48px!important}.mt-6{margin-top:96px!important}.pt-6{padding-top:96px!important}.mb-6{margin-bottom:96px!important}.pb-6{padding-bottom:96px!important}.ml-6{margin-left:96px!important}.pl-6{padding-left:96px!important}.mr-6{margin-right:96px!important}.pr-6{padding-right:96px!important}.m-6{margin:96px!important}.p-6{padding:96px!important}mat-sidenav-container{height:100%}.mat-sidenav,mat-sidenav-container ::ng-deep .mat-drawer-backdrop{z-index:102}.uxg-toolbar{position:fixed;z-index:101}.uxg-nav-header{display:flex;flex-direction:column;align-items:center;justify-content:center}.app-content{position:absolute;top:56px;right:0;bottom:0;left:0;padding:2rem;overflow-x:auto}.theme-toggle{margin-left:16px}"]
            },] }
];
/** @nocollapse */
GlobalNavComponent.ctorParameters = () => [
    { type: Router }
];
GlobalNavComponent.propDecorators = {
    appName: [{ type: Input }],
    navigationNodes: [{ type: Input }],
    activeRoute: [{ type: Input }],
    currentNode: [{ type: Input }],
    brandIcon: [{ type: Input }],
    appContent: [{ type: Input }],
    navbarAction: [{ type: Input }],
    menuClick: [{ type: Output }],
    brandAction: [{ type: Output }],
    nodeChosen: [{ type: Output }],
    logout: [{ type: Output }]
};

class NavbarComponent {
    constructor() {
        this.breadcrumbs = [];
        this.menuClick = new EventEmitter();
        this.brandAction = new EventEmitter();
        this.nodeChosen = new EventEmitter();
    }
    ngOnInit() { }
    ngOnChanges(changes) {
        if (changes.currentNode) {
            this.breadcrumbs = this.buildBreadCrumb(this.appName, this.currentNode);
        }
    }
    ngOnDestroy() { }
    onMenuClick() {
        this.menuClick.emit();
    }
    buildBreadCrumb(appName, currentNode) {
        const breadcrumbs = [];
        if (appName) {
            breadcrumbs.push({
                label: appName,
                url: '/',
                itemClass: 'uxg-h6'
            });
        }
        // Once navigation model evolve to handle deeper levels, this would need to change
        if (currentNode) {
            breadcrumbs.push({
                label: currentNode.title,
                url: currentNode.path
            });
        }
        return breadcrumbs;
    }
}
NavbarComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-navbar',
                template: "<mat-toolbar class=\"uxg-toolbar uxg-toolbar-elevated\">\n  <button\n    class=\"uxg-nav-header-button\"\n    mat-icon-button\n    mat-primary\n    color=\"primary\"\n    (click)=\"onMenuClick()\"\n    aria-label=\"Menu\"\n  >\n    <mat-icon>menu</mat-icon>\n  </button>\n\n  <a\n    href=\"javascript:void(0)\"\n    (click)=\"brandAction.emit($event)\"\n    aria-label=\"Go to Finastra website\"\n    class=\"uxg-logo\"\n    dense\n  ></a>\n\n  <uxg-breadcrumb [breadcrumbs]=\"breadcrumbs\"></uxg-breadcrumb>\n\n  <span class=\"fill-remaining-space\"></span>\n\n  <ng-container *ngTemplateOutlet=\"navbarAction\"></ng-container>\n</mat-toolbar>\n",
                host: {
                    class: 'uxg-navbar'
                },
                styles: ["uxg-navbar{position:unset}.uxg-toolbar{z-index:15;position:relative}.uxg-nav-list-level.mat-nav-list.mat-list-base>.mat-list-item:last-of-type,.uxg-nav-list.mat-nav-list.mat-list-base>.mat-list-item:last-of-type{margin-bottom:0!important}.mat-list-base{padding-top:0!important}"]
            },] }
];
NavbarComponent.propDecorators = {
    brandIcon: [{ type: Input }],
    currentNode: [{ type: Input }],
    navbarAction: [{ type: Input }],
    appName: [{ type: Input }],
    menuClick: [{ type: Output }],
    brandAction: [{ type: Output }],
    nodeChosen: [{ type: Output }]
};

class SidenavComponent {
    constructor(_host, cd) {
        this._host = _host;
        this.cd = cd;
        this.logout = new EventEmitter();
        this.nodeChosen = new EventEmitter();
    }
    ngOnInit() {
        this.iconName = this.getIconName(this.appName);
        this._host.openedChange.subscribe(() => {
            this.currentNodes = this.navigationNodes;
            this.cd.markForCheck();
        });
    }
    ngOnChanges(changes) {
        if (changes.navigationNodes) {
            this.currentNodes = changes.navigationNodes.currentValue;
        }
    }
    getIconName(name) {
        if (!name)
            return name;
        const words = name.replace('-', ' ').split(' ');
        if (words && words.length === 1)
            return name;
        return !words
            ? ''
            : words
                .map((word) => word.substring(0, 1))
                .join('')
                .substring(0, 3);
    }
    onClick(node) {
        this.nodeChosen.emit(node);
        this._host.close();
    }
    isActive(path) {
        if (this.activeRoute)
            return this.activeRoute.includes(path);
    }
}
SidenavComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-sidenav',
                template: "<div class=\"uxg-nav-header\">\n  <mat-card class=\"uxg-card-product\" dense>\n    <span class=\"uxg-h4 uxg-card-product-name\">{{ iconName | uppercase }}</span>\n  </mat-card>\n  <h6 class=\"uxg-h6\">{{ appName | uppercase }}</h6>\n</div>\n\n<mat-nav-list class=\"uxg-nav-list-main uxg-nav-list\">\n  <div mat-subheader>Applications</div>\n  <a\n    mat-list-item\n    (click)=\"onClick(node)\"\n    [ngClass]=\"{ 'uxg-list-item-selected': isActive(node.path) }\"\n    *ngFor=\"let node of navigationNodes\"\n  >\n    <mat-icon mat-list-icon>{{ node.icon }}</mat-icon>\n    <p>{{ node.title }}</p>\n  </a>\n</mat-nav-list>\n\n<mat-nav-list class=\"uxg-link-list\">\n  <a (click)=\"logout.emit()\" mat-list-item>\n    <mat-icon mat-list-icon>power_settings_new</mat-icon>\n    <span class=\"uxg-body-2\">Logout</span>\n  </a>\n</mat-nav-list>\n",
                styles: [":host{display:flex;flex-direction:column;height:100%}:host .uxg-nav-list-main{flex:1}:host .uxg-nav-header{display:flex;flex-direction:column;justify-content:center;align-items:center;padding:16px}:host .uxg-nav-header h6{margin-top:20px}:host mat-nav-list:last-child{margin-bottom:30px}"]
            },] }
];
/** @nocollapse */
SidenavComponent.ctorParameters = () => [
    { type: MatSidenav, decorators: [{ type: Inject, args: [forwardRef(() => MatSidenav),] }] },
    { type: ChangeDetectorRef }
];
SidenavComponent.propDecorators = {
    appName: [{ type: Input }],
    navigationNodes: [{ type: Input }],
    activeRoute: [{ type: Input }],
    logout: [{ type: Output }],
    nodeChosen: [{ type: Output }]
};

class GlobalNavModule {
}
GlobalNavModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    MatToolbarModule,
                    MatButtonModule,
                    MatIconModule,
                    MatSidenavModule,
                    MatButtonModule,
                    MatCardModule,
                    MatListModule,
                    UxgBreadcrumbModule
                ],
                declarations: [GlobalNavComponent, NavbarComponent, SidenavComponent],
                exports: [GlobalNavComponent, NavbarComponent, SidenavComponent]
            },] }
];

// Pulled all interfaces out of `navigation.service.ts` because of this:

/**
 * Generated bundle index. Do not edit.
 */

export { GlobalNavComponent, GlobalNavModule, NavbarComponent as ɵa, SidenavComponent as ɵb };
//# sourceMappingURL=ffdc-uxg-angular-components-global-nav.js.map
