import { Overlay, OverlayModule } from '@angular/cdk/overlay';
import { CommonModule } from '@angular/common';
import { InjectionToken, EventEmitter, Component, ViewEncapsulation, Inject, Input, Output, ViewChild, HostListener, ɵɵdefineInjectable, ɵɵinject, INJECTOR, Injectable, Injector, NgModule } from '@angular/core';
import { FlexLayoutModule } from '@angular/flex-layout';
import { FormsModule } from '@angular/forms';
import { MatButtonModule } from '@angular/material/button';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatIconModule } from '@angular/material/icon';
import { MatListModule } from '@angular/material/list';
import { MatInputModule } from '@angular/material/input';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { ReplaySubject, fromEvent, Subject } from 'rxjs';
import { distinctUntilChanged, debounceTime } from 'rxjs/operators';
import { ComponentPortal, PortalInjector } from '@angular/cdk/portal';

class SearchOverlayRef {
    constructor(overlay) {
        this.overlay = overlay;
    }
    close() {
        this.overlay.detach();
    }
}

const SEARCH_CONFIG = new InjectionToken('SEARCH_CONFIG');

const ANIMATION_TIMINGS = '300ms cubic-bezier(0.25, 0.8, 0.25, 1)';
class GlobalSearchOverlayComponent {
    constructor(ref, config) {
        this.ref = ref;
        this.config = config;
        this.animationState = 'enter';
        this.results$ = new ReplaySubject(1);
        this.resultsShown = 0;
        this.resultsFound = 0;
        this.filterSize = 0;
        this.searchValue = '';
        this.searchTime = '';
        this.resultStatusTemplate = this.config.resultStatusTemplate;
        this.emptySearchTemplate = this.config.emptySearchTemplate;
        this.resultItemTemplate = this.config.resultItemTemplate;
        this.groupBy = this.config.groupBy;
        this.showFilter = this.config.showFilter;
        this.maxItems = this.config.maxItems;
        this.itemDivider = this.config.itemDivider;
        this.groupDivider = this.config.groupDivider;
        this.itemsLayout = this.config.itemsLayout;
        this.results = this.config.results;
        this.searchTermChange = new EventEmitter();
        this.itemClick = new EventEmitter();
        this.searchClose = new EventEmitter();
        this.searchDebounce = 300;
    }
    handleKeydown(event) {
        this.closeSearch();
    }
    ngAfterViewInit() {
        setTimeout(() => this.searchInput.nativeElement.focus());
        let t0, t1;
        fromEvent(this.searchInput.nativeElement, 'input')
            .pipe(distinctUntilChanged(), debounceTime(this.searchDebounce))
            .subscribe(() => {
            const value = this.searchInput.nativeElement.value;
            this.searchValue = value;
            this.searchTermChange.emit(value);
            t0 = performance.now();
        });
        this.results.subscribe((results) => {
            this.resultsFound = this.resultsShown = results.length;
            const groupedResults = this.groupByResults(results, this.groupBy);
            this.filterSize = 0;
            this.results$.next(groupedResults);
            t1 = performance.now();
            this.searchTime = (t1 - t0).toLocaleString();
        });
    }
    closeSearch() {
        this.ref.close();
        this.searchClose.emit();
    }
    onItemClick(item) {
        this.itemClick.emit(item);
    }
    toggleFilter(resultGroup) {
        resultGroup.selected = !resultGroup.selected;
        if (resultGroup.selected) {
            if (this.filterSize === 0) {
                this.resultsShown = 0;
            }
            this.filterSize++;
            this.resultsShown += resultGroup.value.length;
        }
        else {
            this.filterSize--;
            if (this.filterSize === 0) {
                this.resultsShown = this.resultsFound;
            }
            else {
                this.resultsShown -= resultGroup.value.length;
            }
        }
        const resultsArea = document.querySelector('.uxg-global-search-results-area');
        if (resultsArea) {
            resultsArea.scrollTo(0, 0);
        }
    }
    get(object, path, defaultVal) {
        const PATH = Array.isArray(path) ? path : path.split('.').filter((i) => i.length);
        if (!PATH.length) {
            return object === undefined ? defaultVal : object;
        }
        if (object === null || object === undefined || typeof object[PATH[0]] === 'undefined') {
            return defaultVal;
        }
        const firstPathItem = PATH.shift();
        return this.get(firstPathItem ? object[firstPathItem] : undefined, PATH, defaultVal);
    }
    groupByResults(collection, property = '') {
        if (!collection) {
            return [];
        }
        const groupedCollection = collection.reduce((previous, current) => {
            if (!previous[this.get(current, property || '')]) {
                previous[this.get(current, property)] = [current];
            }
            else {
                previous[this.get(current, property)].push(current);
            }
            return previous;
        }, {});
        return Object.keys(groupedCollection).map((key) => ({
            key,
            value: groupedCollection[key]
        }));
    }
}
GlobalSearchOverlayComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-global-search-overlay',
                template: "<div fxLayout=\"column\" class=\"uxg-global-search-overlay\" fxFlexFill>\n  <div fxFlex=\"5\" class=\"uxg-global-search-close-overlay-button\">\n    <button mat-icon-button (click)=\"closeSearch()\" extra-large>\n      <mat-icon>clear</mat-icon>\n    </button>\n  </div>\n  <div\n    fxFlex=\"30\"\n    fxFlex.lt-lg=\"20\"\n    fxFlex.xs=\"15\"\n    fxLayout=\"row\"\n    [@slideContent]=\"animationState\"\n    class=\"uxg-global-search-input-area\"\n  >\n    <mat-form-field floatLabel=\"never\" class=\"uxg-global-search-input\">\n      <mat-icon #searchIcon color=\"primary\" matPrefix class=\"uxg-global-search-icon\">search</mat-icon>\n      <input\n        matInput\n        #searchInput\n        type=\"search\"\n        placeholder=\"Search\"\n        autocomplete=\"off\"\n        spellcheck=\"false\"\n        aria-label=\"Global search\"\n      />\n    </mat-form-field>\n  </div>\n  <ng-container *ngIf=\"results$ | async as results; else emptySearch\">\n    <ng-container *ngIf=\"results.length; else empty\">\n      <div\n        fxFlex=\"65\"\n        fxFlex.lt-lg=\"75\"\n        fxFlex.xs=\"80\"\n        fxLayout\n        fxLayout.lt-lg=\"column\"\n        class=\"uxg-global-search-container-parent\"\n      >\n        <div\n          fxLayout=\"column\"\n          fxFlex=\"{{ showFilter ? '70' : 'auto' }}\"\n          fxFlex.lt-lg=\"auto\"\n          class=\"uxg-global-search-results-container\"\n        >\n          <!-- results status area -->\n          <ng-container [ngTemplateOutlet]=\"resultStatusTemplate\"></ng-container>\n          <div class=\"uxg-global-search-results-counter\">\n            Showing {{ resultsShown }} out of {{ resultsFound }} results\n            <span class=\"uxg-caption\">&nbsp;&nbsp;({{ searchTime }} seconds)</span>\n          </div>\n          <!-- results area -->\n          <div class=\"uxg-global-search-results-area\">\n            <ng-container *ngFor=\"let resultGroup of results\">\n              <ng-container *ngIf=\"!groupBy || (groupBy && (filterSize === 0 || (resultGroup.selected && filterSize)))\">\n                <div\n                  *ngIf=\"groupBy && resultGroup.key !== 'undefined' && resultGroup.value.length\"\n                  class=\"uxg-global-search-result-group-header\"\n                >\n                  <h4 class=\"uxg-h4\">{{ resultGroup.key }}</h4>\n                  <span class=\"uxg-global-search-result-group-counter\">({{ resultGroup.value.length }})</span>\n                </div>\n                <div class=\"uxg-global-search-result-group-container\" [fxLayout]=\"itemsLayout\">\n                  <div *ngFor=\"let result of resultGroup.value; let last = last\">\n                    <div class=\"uxg-global-search-result-item\" (click)=\"onItemClick(result)\">\n                      <ng-container\n                        *ngTemplateOutlet=\"resultItemTemplate || defaultTemplate; context: { $implicit: result }\"\n                      >\n                      </ng-container>\n                    </div>\n                    <mat-divider [inset]=\"true\" *ngIf=\"itemDivider && !last\"></mat-divider>\n                  </div>\n                </div>\n                <mat-divider *ngIf=\"groupBy && groupDivider\"></mat-divider>\n              </ng-container>\n            </ng-container>\n          </div>\n        </div>\n        <!-- filter area -->\n        <ng-container *ngIf=\"groupBy && showFilter\">\n          <mat-divider fxHide.lt-lg [vertical]=\"true\"></mat-divider>\n          <div\n            fxLayout=\"column\"\n            fxLayout.lt-lg=\"row wrap\"\n            fxFlexOrder.lt-lg=\"-1\"\n            class=\"uxg-global-search-results-filter\"\n          >\n            <h5 class=\"uxg-h5\">Filter results by</h5>\n            <ng-container *ngFor=\"let resultGroup of results\">\n              <mat-checkbox color=\"primary\" [checked]=\"resultGroup.selected\" (change)=\"toggleFilter(resultGroup)\">\n                {{ resultGroup.key }} ({{ resultGroup.value.length }})\n              </mat-checkbox>\n            </ng-container>\n          </div>\n          <mat-divider fxHide.gt-md></mat-divider>\n        </ng-container>\n      </div>\n    </ng-container>\n  </ng-container>\n</div>\n\n<ng-template #empty>\n  <ng-container *ngIf=\"searchValue.length; else emptySearch\">\n    <div fxFlex=\"5\" class=\"uxg-global-search-results-counter\">No results found</div>\n  </ng-container>\n</ng-template>\n\n<ng-template #emptySearch>\n  <ng-container *ngTemplateOutlet=\"emptySearchTemplate\"> </ng-container>\n</ng-template>\n\n<ng-template #defaultTemplate let-result>\n  <div fxLayout=\"column\">\n    <h5 class=\"uxg-subtitle-1\">{{ result.title }}</h5>\n    <div class=\"uxg-caption\">\n      {{ result.body }}\n    </div>\n  </div>\n</ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                animations: [
                    trigger('slideContent', [
                        state('void', style({ transform: 'translate3d(0, -30%, 0) scale(0.85)', opacity: 0 })),
                        state('enter', style({ transform: 'none', opacity: 1 })),
                        state('leave', style({ transform: 'translate3d(0, -30%, 0)', opacity: 0 })),
                        transition('* => *', animate(ANIMATION_TIMINGS))
                    ])
                ]
            },] }
];
/** @nocollapse */
GlobalSearchOverlayComponent.ctorParameters = () => [
    { type: SearchOverlayRef },
    { type: undefined, decorators: [{ type: Inject, args: [SEARCH_CONFIG,] }] }
];
GlobalSearchOverlayComponent.propDecorators = {
    resultStatusTemplate: [{ type: Input }],
    emptySearchTemplate: [{ type: Input }],
    resultItemTemplate: [{ type: Input }],
    groupBy: [{ type: Input }],
    showFilter: [{ type: Input }],
    maxItems: [{ type: Input }],
    itemDivider: [{ type: Input }],
    groupDivider: [{ type: Input }],
    itemsLayout: [{ type: Input }],
    results: [{ type: Input }],
    searchTermChange: [{ type: Output }],
    itemClick: [{ type: Output }],
    searchClose: [{ type: Output }],
    searchInput: [{ type: ViewChild, args: ['searchInput', { static: true },] }],
    handleKeydown: [{ type: HostListener, args: ['document:keydown.escape', ['$event'],] }]
};

class GlobalSearchOverlayService {
    constructor(overlay, parentInjector) {
        this.overlay = overlay;
        this.parentInjector = parentInjector;
    }
    open(config) {
        const overlayRef = this.overlay.create({
            positionStrategy: this.overlay.position().global(),
            scrollStrategy: this.overlay.scrollStrategies.block(),
            hasBackdrop: true,
            backdropClass: 'uxg-global-search-overlay-backdrop',
            panelClass: 'uxg-global-search-overlay-pane'
        });
        const searchOverlayRef = new SearchOverlayRef(overlayRef);
        const injector = config ? this.getInjector(config, searchOverlayRef, this.parentInjector) : this.parentInjector;
        const containerPortal = new ComponentPortal(GlobalSearchOverlayComponent, null, injector);
        const componentRef = overlayRef.attach(containerPortal);
        const element = componentRef.location.nativeElement;
        element.style.width = '100%';
        componentRef.instance.searchTermChange.subscribe((value) => {
            if (config)
                config.searchTermChange(value);
        });
        componentRef.instance.itemClick.subscribe((value) => {
            if (config)
                config.itemClick(value);
        });
        componentRef.instance.searchClose.subscribe((value) => {
            if (config)
                config.searchClose(value);
        });
        return [searchOverlayRef, componentRef];
    }
    getInjector(config, overlayRef, parentInjector) {
        const tokens = new WeakMap();
        tokens.set(SearchOverlayRef, overlayRef);
        tokens.set(SEARCH_CONFIG, config || {});
        return new PortalInjector(parentInjector, tokens);
    }
}
/** @nocollapse */ GlobalSearchOverlayService.ɵprov = ɵɵdefineInjectable({ factory: function GlobalSearchOverlayService_Factory() { return new GlobalSearchOverlayService(ɵɵinject(Overlay), ɵɵinject(INJECTOR)); }, token: GlobalSearchOverlayService, providedIn: "root" });
GlobalSearchOverlayService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
GlobalSearchOverlayService.ctorParameters = () => [
    { type: Overlay },
    { type: Injector }
];

class UxgGlobalSearch {
    constructor(overlayService) {
        this.overlayService = overlayService;
        this.showFilter = true;
        this.itemDivider = false;
        this.groupDivider = false;
        this.itemsLayout = 'column';
        this.results = [];
        this.resultItemClick = new EventEmitter();
        this.searchTermChange = new EventEmitter();
        this.searchClose = new EventEmitter();
        this.results$ = new Subject();
    }
    get searchInput() {
        var _a;
        return (_a = this.componentRef) === null || _a === void 0 ? void 0 : _a.instance.searchInput;
    }
    openSearch() {
        [this.ref, this.componentRef] = this.overlayService.open({
            resultStatusTemplate: this.resultStatusTemplate,
            emptySearchTemplate: this.emptySearchTemplate,
            resultItemTemplate: this.resultItemTemplate,
            showFilter: this.showFilter,
            groupBy: this.groupBy,
            itemDivider: this.itemDivider,
            groupDivider: this.groupDivider,
            maxItems: this.maxItems,
            itemsLayout: this.itemsLayout,
            searchTermChange: ($event) => this.searchTermChange.emit($event),
            itemClick: ($event) => {
                this.resultItemClick.emit($event);
                this.searchClose.emit($event);
                if (this.ref)
                    this.ref.close();
            },
            searchClose: ($event) => this.searchClose.emit($event),
            results: this.results$
        });
    }
    closeSearch() {
        if (this.ref)
            this.ref.close();
    }
    ngOnChanges(changes) {
        if (changes.hasOwnProperty('results') && !changes.results.firstChange) {
            this.results$.next(changes.results.currentValue);
        }
    }
}
UxgGlobalSearch.decorators = [
    { type: Component, args: [{
                selector: 'uxg-global-search',
                template: "<ng-content></ng-content>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".mt-0{margin-top:0!important}.pt-0{padding-top:0!important}.mb-0{margin-bottom:0!important}.pb-0{padding-bottom:0!important}.ml-0{margin-left:0!important}.pl-0{padding-left:0!important}.mr-0{margin-right:0!important}.pr-0{padding-right:0!important}.m-0{margin:0!important}.p-0{padding:0!important}.mt-1{margin-top:4px!important}.pt-1{padding-top:4px!important}.mb-1{margin-bottom:4px!important}.pb-1{padding-bottom:4px!important}.ml-1{margin-left:4px!important}.pl-1{padding-left:4px!important}.mr-1{margin-right:4px!important}.pr-1{padding-right:4px!important}.m-1{margin:4px!important}.p-1{padding:4px!important}.mt-2{margin-top:8px!important}.pt-2{padding-top:8px!important}.mb-2{margin-bottom:8px!important}.pb-2{padding-bottom:8px!important}.ml-2{margin-left:8px!important}.pl-2{padding-left:8px!important}.mr-2{margin-right:8px!important}.pr-2{padding-right:8px!important}.m-2{margin:8px!important}.p-2{padding:8px!important}.mt-3{margin-top:16px!important}.pt-3{padding-top:16px!important}.mb-3{margin-bottom:16px!important}.pb-3{padding-bottom:16px!important}.ml-3{margin-left:16px!important}.pl-3{padding-left:16px!important}.mr-3{margin-right:16px!important}.pr-3{padding-right:16px!important}.m-3{margin:16px!important}.p-3{padding:16px!important}.mt-4{margin-top:24px!important}.pt-4{padding-top:24px!important}.mb-4{margin-bottom:24px!important}.pb-4{padding-bottom:24px!important}.ml-4{margin-left:24px!important}.pl-4{padding-left:24px!important}.mr-4{margin-right:24px!important}.pr-4{padding-right:24px!important}.m-4{margin:24px!important}.p-4{padding:24px!important}.mt-5{margin-top:48px!important}.pt-5{padding-top:48px!important}.mb-5{margin-bottom:48px!important}.pb-5{padding-bottom:48px!important}.ml-5{margin-left:48px!important}.pl-5{padding-left:48px!important}.mr-5{margin-right:48px!important}.pr-5{padding-right:48px!important}.m-5{margin:48px!important}.p-5{padding:48px!important}.mt-6{margin-top:96px!important}.pt-6{padding-top:96px!important}.mb-6{margin-bottom:96px!important}.pb-6{padding-bottom:96px!important}.ml-6{margin-left:96px!important}.pl-6{padding-left:96px!important}.mr-6{margin-right:96px!important}.pr-6{padding-right:96px!important}.m-6{margin:96px!important}.p-6{padding:96px!important}.uxg-global-search-overlay-pane{width:100%}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-input-area{justify-content:center;align-items:center}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-input-area .uxg-global-search-input{width:50%;height:200px}@media (max-width:1279.9px){.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-input-area .uxg-global-search-input{width:65%}}@media (min-width:0) and (max-width:599.9px){.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-input-area .uxg-global-search-input{width:80%}}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-input-area .uxg-global-search-icon{height:99px;display:flex;align-items:center;margin-right:16px}@media (min-width:0) and (max-width:599.9px){.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-input-area .uxg-global-search-icon{height:50px}}@media (min-width:0) and (max-width:599.9px){.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-input-area .mat-form-field-infix{padding-bottom:0}}@media (min-width:0) and (max-width:599.9px){.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-input-area .mat-form-field-infix .mat-form-field-label-wrapper{left:4px;top:.2em}}@media (min-width:0) and (max-width:599.9px){.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-input-area .mat-input-element{height:50px;padding:1.5rem .2rem}}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-close-overlay-button button{float:right;margin:8px;width:48px;height:48px}@media (min-width:0) and (max-width:599.9px){.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-close-overlay-button button{width:32px;height:32px}}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-close-overlay-button button .mat-button-wrapper{width:48px;height:48px}@media (min-width:0) and (max-width:599.9px){.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-close-overlay-button button .mat-button-wrapper{width:32px;height:32px}}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-close-overlay-button button .mat-button-wrapper .mat-icon{width:48px;height:48px;line-height:48px;font-size:48px}@media (min-width:0) and (max-width:599.9px){.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-close-overlay-button button .mat-button-wrapper .mat-icon{width:32px!important;height:32px!important;line-height:32px!important;font-size:32px!important}}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent .uxg-global-search-results-container{overflow:hidden}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent .uxg-global-search-results-container .uxg-global-search-results-area{overflow:auto;padding:1rem 5rem 2rem;height:100%;outline:none}@media (max-width:1279.9px){.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent .uxg-global-search-results-container .uxg-global-search-results-area{padding:1rem 2rem 2rem}}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent .uxg-global-search-results-container .uxg-global-search-results-area .uxg-global-search-result-group-header{display:flex;padding-top:16px}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent .uxg-global-search-results-container .uxg-global-search-results-area .uxg-global-search-result-group-header .uxg-h4{margin:0;display:flex;align-items:center}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent .uxg-global-search-results-container .uxg-global-search-results-area .uxg-global-search-result-group-header .uxg-global-search-result-group-counter{margin-left:8px}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent .uxg-global-search-results-container .uxg-global-search-results-area .uxg-global-search-result-group-container{padding-top:8px;padding-bottom:16px}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent .uxg-global-search-results-container .uxg-global-search-results-area .uxg-global-search-result-group-container .uxg-global-search-result-item{cursor:pointer;margin:8px 16px 8px 0}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent .uxg-global-search-results-filter{padding:0 5rem}@media (max-width:1279.9px){.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent .uxg-global-search-results-filter{padding:1rem 2rem}}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent .uxg-global-search-results-filter .mat-checkbox{padding:4px 0}@media (max-width:1279.9px){.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent .uxg-global-search-results-filter .mat-checkbox{margin-right:16px}}@media (max-width:1279.9px){.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent .uxg-global-search-results-filter .uxg-h5{width:100%}}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent mat-divider{margin-bottom:2rem}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-container-parent mat-divider.mat-divider-horizontal{order:-1;margin:0 2rem 16px}.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-results-counter{display:flex;align-items:center;padding-left:5rem;width:100%}@media (max-width:1279.9px){.uxg-global-search-overlay-pane uxg-global-search-overlay .uxg-global-search-results-counter{padding-left:2rem}}.uxg-global-search-overlay-pane uxg-global-search-overlay .cdk-global-scrollblock{position:static;width:auto;overflow:hidden}"]
            },] }
];
/** @nocollapse */
UxgGlobalSearch.ctorParameters = () => [
    { type: GlobalSearchOverlayService }
];
UxgGlobalSearch.propDecorators = {
    groupBy: [{ type: Input }],
    resultItemTemplate: [{ type: Input }],
    emptySearchTemplate: [{ type: Input }],
    resultStatusTemplate: [{ type: Input }],
    showFilter: [{ type: Input }],
    maxItems: [{ type: Input }],
    itemDivider: [{ type: Input }],
    groupDivider: [{ type: Input }],
    itemsLayout: [{ type: Input }],
    results: [{ type: Input }],
    resultItemClick: [{ type: Output }],
    searchTermChange: [{ type: Output }],
    searchClose: [{ type: Output }]
};

class GlobalSearchModule {
}
GlobalSearchModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    MatButtonModule,
                    MatIconModule,
                    MatListModule,
                    MatCheckboxModule,
                    MatFormFieldModule,
                    FormsModule,
                    MatInputModule,
                    OverlayModule,
                    FlexLayoutModule.withConfig({ useColumnBasisZero: false })
                ],
                exports: [UxgGlobalSearch, GlobalSearchOverlayComponent],
                declarations: [UxgGlobalSearch, GlobalSearchOverlayComponent]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { GlobalSearchModule, GlobalSearchOverlayComponent, UxgGlobalSearch, GlobalSearchOverlayService as ɵa, SEARCH_CONFIG as ɵb, SearchOverlayRef as ɵc };
//# sourceMappingURL=ffdc-uxg-angular-components-global-search.js.map
