import { EventEmitter, Type, Component, ViewEncapsulation, ComponentFactoryResolver, Input, Output, ViewChild, ViewContainerRef, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { MatTableModule } from '@angular/material/table';
import { ScrollingModule } from '@angular/cdk/scrolling';
import { ScrollingModule as ScrollingModule$1 } from '@angular/cdk-experimental/scrolling';

class RepeaterComponent {
    constructor(resolver) {
        this.resolver = resolver;
        this._data = [];
        this.orientation = 'horizontal';
        this.multiSelect = false;
        this.space = '0px';
        this.columnsMatcher = {};
        this.selectedKeys = [];
        this.selectionChange = new EventEmitter();
        this.selectedItems = {};
    }
    get data() {
        return this._data;
    }
    set data(data) {
        this._data = data;
    }
    ngOnInit() {
        if (this.component instanceof Type) {
            this.componentFactory = this.resolver.resolveComponentFactory(this.component);
        }
    }
    onClick(index, value) {
        if (!this.selectedItems) {
            this.selectedItems = {};
        }
        if (!this.multiSelect && !this.selectedItems[index]) {
            this.selectedItems = { [index]: value };
        }
        else if (!this.multiSelect && this.selectedItems[index]) {
            this.selectedItems = {};
        }
        else if (this.multiSelect && this.selectedItems[index]) {
            delete this.selectedItems[index];
        }
        else {
            this.selectedItems[index] = value;
        }
        this.selectionChange.emit({ value: this.selectedItems });
    }
    isSelected(index) {
        return this.selectedItems && this.selectedItems[index] !== null && this.selectedItems[index] !== undefined;
    }
    ngOnChanges(changes) {
        if (changes.orientation) {
            this.orientation = changes.orientation.currentValue;
        }
        if (changes.multiSelect) {
            this.multiSelect = changes.multiSelect.currentValue;
            this.selectedItems = {};
        }
        if (changes.component) {
            this.componentFactory = this.resolver.resolveComponentFactory(changes.component.currentValue);
        }
        if (changes.selectedKeys) {
            this.selectedKeys = changes.selectedKeys.currentValue;
            this.selectedItems = {};
            if (!this.multiSelect && this.selectedKeys.length > 0) {
                this.selectedItems[this.selectedKeys[0]] = this.data[this.selectedKeys[0]];
            }
            if (this.multiSelect && this.multiSelect) {
                this.selectedKeys.forEach((selectionIndex) => {
                    this.selectedItems[selectionIndex] = this.data[selectionIndex];
                });
            }
        }
    }
}
RepeaterComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-repeater',
                template: "<cdk-virtual-scroll-viewport autosize class=\"viewport\" [orientation]=\"orientation\">\n  <div\n    *cdkVirtualFor=\"let value of data; let odd = odd; let index = index\"\n    class=\"repeater-item\"\n    [class.alternate]=\"odd\"\n    (click)=\"onClick(index, value)\"\n  >\n    <uxg-component-repeater\n      [factory]=\"componentFactory\"\n      [data]=\"value\"\n      [columnsMatcher]=\"columnsMatcher\"\n      [ngStyle]=\"{\n        'margin-right': orientation === 'horizontal' ? space : '0px',\n        'margin-bottom': orientation === 'vertical' ? space : '0px'\n      }\"\n      [selected]=\"isSelected(index)\"\n    ></uxg-component-repeater>\n  </div>\n</cdk-virtual-scroll-viewport>\n",
                encapsulation: ViewEncapsulation.None,
                styles: ["uxg-repeater .cdk-virtual-scroll-orientation-horizontal .cdk-virtual-scroll-content-wrapper{flex-direction:row;display:flex}uxg-repeater .repeater-item{display:flex}"]
            },] }
];
/** @nocollapse */
RepeaterComponent.ctorParameters = () => [
    { type: ComponentFactoryResolver }
];
RepeaterComponent.propDecorators = {
    data: [{ type: Input }],
    component: [{ type: Input }],
    orientation: [{ type: Input }],
    multiSelect: [{ type: Input }],
    space: [{ type: Input }],
    columnsMatcher: [{ type: Input }],
    selectedKeys: [{ type: Input }],
    selectionChange: [{ type: Output }]
};

class ComponentRepeaterComponent {
    constructor() {
        this._columnsMatcher = {};
        this._selected = false;
    }
    set factory(data) {
        this._factory = data;
        this.updateComponent();
    }
    set data(data) {
        this._data = data;
        if (this.ref) {
            this.ref.instance.data = this._data;
            if (this.ref.instance.cd) {
                this.ref.instance.cd.detectChanges();
            }
        }
    }
    set columnsMatcher(data) {
        this._columnsMatcher = data;
        if (this.ref) {
            this.ref.instance.columnsMatcher = this._columnsMatcher;
            if (this.ref.instance.cd) {
                this.ref.instance.cd.detectChanges();
            }
        }
    }
    set selected(selected) {
        this._selected = selected;
        if (this.ref) {
            this.ref.instance.selected = this._selected;
            if (this.ref.instance.cd) {
                this.ref.instance.cd.detectChanges();
            }
        }
    }
    ngOnInit() {
        this.updateComponent();
    }
    updateComponent() {
        if (this._factory) {
            if (this.ref) {
                this.ref.destroy();
            }
            this.ref = this.componentHolder.createComponent(this._factory);
            if (this._data) {
                this.ref.instance.data = this._data;
            }
            if (this._columnsMatcher) {
                this.ref.instance.columnsMatcher = this._columnsMatcher;
            }
            if (this._selected) {
                this.ref.instance.selected = this._selected;
            }
            if (this.ref.instance.cd) {
                this.ref.instance.cd.detectChanges();
            }
        }
    }
}
ComponentRepeaterComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-component-repeater',
                template: "<ng-container #componentHolder></ng-container>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            },] }
];
/** @nocollapse */
ComponentRepeaterComponent.ctorParameters = () => [];
ComponentRepeaterComponent.propDecorators = {
    factory: [{ type: Input }],
    data: [{ type: Input }],
    columnsMatcher: [{ type: Input }],
    selected: [{ type: Input }],
    componentHolder: [{ type: ViewChild, args: ['componentHolder', { read: ViewContainerRef, static: true },] }]
};

class RepeaterModule {
}
RepeaterModule.decorators = [
    { type: NgModule, args: [{
                declarations: [RepeaterComponent, ComponentRepeaterComponent],
                imports: [CommonModule, MatTableModule, ScrollingModule, ScrollingModule$1],
                exports: [RepeaterComponent]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { ComponentRepeaterComponent, RepeaterComponent, RepeaterModule };
//# sourceMappingURL=ffdc-uxg-angular-components-repeater.js.map
