import { CommonModule } from '@angular/common';
import { Component, Input, NgModule } from '@angular/core';
import { MatButtonModule } from '@angular/material/button';
import { MatIconModule } from '@angular/material/icon';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { Subscription, BehaviorSubject, fromEvent } from 'rxjs';
import { throttleTime, map, distinctUntilChanged, share } from 'rxjs/operators';
import { polyfill } from 'smoothscroll-polyfill';

var ShowStatus;
(function (ShowStatus) {
    ShowStatus["show"] = "show";
    ShowStatus["hide"] = "hide";
})(ShowStatus || (ShowStatus = {}));
class ScrollToTopComponent {
    constructor() {
        this.showAfter = 500;
        this.showButton = false;
        this.scroll$ = Subscription.EMPTY;
        this.state$ = new BehaviorSubject(ShowStatus.hide);
    }
    ngAfterViewInit() {
        polyfill();
        if (this.parentElementSelector) {
            this.parent = document.querySelector(this.parentElementSelector);
        }
        else {
            this.parent = window;
        }
        this.scroll$ = fromEvent(this.parent, 'scroll')
            .pipe(throttleTime(10), map(() => this.parent.pageYOffset || this.parent.scrollTop), map((y) => {
            if (y > this.showAfter) {
                return ShowStatus.show;
            }
            else {
                return ShowStatus.hide;
            }
        }), distinctUntilChanged(), share())
            .subscribe((s) => this.state$.next(s));
    }
    ngOnDestroy() {
        this.scroll$.unsubscribe();
    }
    onClick() {
        this.parent.scroll({ top: 0, left: 0, behavior: 'smooth' });
    }
}
ScrollToTopComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-scroll-to-top',
                template: "<div class=\"scroll-to-top-container\" (click)=\"onClick()\" [@scrollAnimation]=\"state$ | async\">\n  <ng-container *ngTemplateOutlet=\"customTemplate || defaultTemplate\"> </ng-container>\n</div>\n\n<ng-template #defaultTemplate>\n  <button mat-fab color=\"gradient\" aria-label=\"Scroll to top\">\n    <mat-icon>keyboard_arrow_up</mat-icon>\n  </button>\n</ng-template>\n",
                animations: [
                    trigger('scrollAnimation', [
                        state('show', style({ opacity: 1, transform: 'scale(1)' })),
                        state('hide', style({ opacity: 0, transform: 'scale(0)' })),
                        transition('show => hide', animate('350ms ease-out')),
                        transition('hide => show', animate('350ms ease-in'))
                    ])
                ],
                styles: [":host{position:fixed;z-index:5;right:20px;bottom:50px}"]
            },] }
];
/** @nocollapse */
ScrollToTopComponent.ctorParameters = () => [];
ScrollToTopComponent.propDecorators = {
    customTemplate: [{ type: Input }],
    showAfter: [{ type: Input }],
    parentElementSelector: [{ type: Input }]
};

class ScrollToTopModule {
}
ScrollToTopModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, MatButtonModule, MatIconModule, BrowserAnimationsModule],
                declarations: [ScrollToTopComponent],
                exports: [ScrollToTopComponent]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { ScrollToTopComponent, ScrollToTopModule };
//# sourceMappingURL=ffdc-uxg-angular-components-scroll-to-top.js.map
