import { EventEmitter, Component, ViewEncapsulation, ChangeDetectionStrategy, Attribute, Input, Output, NgModule } from '@angular/core';
import { Subject } from 'rxjs';
import { debounceTime, distinctUntilChanged } from 'rxjs/operators';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { CommonModule } from '@angular/common';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatInputModule } from '@angular/material/input';
import { MatIconModule } from '@angular/material/icon';
import { MatButtonModule } from '@angular/material/button';

class UxgSearchInputComponent {
    constructor(dense) {
        this.dense = dense;
        this.query = '';
        this.placeholder = 'Search';
        this.debounceTime = 400;
        this.search = new EventEmitter();
        this.term$ = new Subject();
        this.termSubscription = this.term$
            .pipe(debounceTime(this.debounceTime), distinctUntilChanged())
            .subscribe((query) => {
            this.search.emit(query);
        });
    }
    ngOnDestroy() {
        this.termSubscription.unsubscribe();
    }
}
UxgSearchInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-search-input',
                template: "<mat-form-field appearance=\"fill\" [attr.dense]=\"dense === '' ? '' : null\">\n  <mat-icon color=\"primary\" matPrefix>search</mat-icon>\n  <input\n    #searchInput=\"matInput\"\n    matInput\n    type=\"text\"\n    placeholder=\"{{ placeholder }}\"\n    [value]=\"query\"\n    (input)=\"term$.next($event.target.value)\"\n    aria-label=\"Search input\"\n  />\n  <button\n    [@showHide]=\"searchInput.value ? 'show' : 'hide'\"\n    (click)=\"searchInput.value = ''; term$.next('')\"\n    matSuffix\n    mat-icon-button\n    aria-label=\"Clear\"\n  >\n    <mat-icon>clear</mat-icon>\n  </button>\n  <mat-hint *ngIf=\"hint\">{{ hint }}</mat-hint>\n</mat-form-field>\n",
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush,
                host: {
                    class: 'uxg-search-input'
                },
                animations: [
                    trigger('showHide', [
                        state('show', style({
                            opacity: 1,
                            visibility: 'visible'
                        })),
                        state('hide', style({
                            opacity: 0,
                            visibility: 'hidden'
                        })),
                        transition('show => hide', [animate('0.3s ease-out')]),
                        transition('hide => show', [animate('0.2s ease-in')])
                    ])
                ],
                styles: [".uxg-search-input{display:flex}.uxg-search-input .mat-form-field{flex:1}"]
            },] }
];
/** @nocollapse */
UxgSearchInputComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Attribute, args: ['dense',] }] }
];
UxgSearchInputComponent.propDecorators = {
    query: [{ type: Input }],
    placeholder: [{ type: Input }],
    debounceTime: [{ type: Input }],
    hint: [{ type: Input }],
    search: [{ type: Output }]
};

class UxgSearchInputModule {
}
UxgSearchInputModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, MatFormFieldModule, MatInputModule, MatIconModule, MatButtonModule],
                exports: [UxgSearchInputComponent],
                declarations: [UxgSearchInputComponent]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { UxgSearchInputComponent, UxgSearchInputModule };
//# sourceMappingURL=ffdc-uxg-angular-components-search-input.js.map
