import { Component, ViewChild, ChangeDetectorRef, ContentChildren, Input, NgModule } from '@angular/core';
import { MatIconModule } from '@angular/material/icon';
import { CommonModule } from '@angular/common';

class StatusStepComponent {
}
StatusStepComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-status-step',
                template: "<ng-template #template let-isCurrent=\"isCurrent\">\n  <div class=\"uxg-step-label\" [class.current]=\"isCurrent\">\n    <span class=\"uxg-body-1\"><ng-content select=\"[step-title]\"></ng-content></span>\n    <span class=\"uxg-body-2\"><ng-content></ng-content></span>\n  </div>\n</ng-template>\n",
                styles: [".uxg-step-label{display:flex;flex-direction:column;align-items:center;white-space:nowrap}"]
            },] }
];
StatusStepComponent.propDecorators = {
    template: [{ type: ViewChild, args: ['template',] }]
};

class HorizontalStatusStepperComponent {
    constructor(cdr) {
        this.cdr = cdr;
        this.currentStep = -1;
    }
    ngAfterViewInit() {
        this.cdr.detectChanges();
    }
    isComplete(stepNumber) {
        return stepNumber < this.currentStep;
    }
    isCurrent(stepNumber) {
        return stepNumber === this.currentStep;
    }
}
HorizontalStatusStepperComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-horizontal-status-stepper',
                template: "<ng-container *ngFor=\"let step of steps; let isLast = last; let isFirst = first; let index = index\">\n  <div class=\"horizontal-stepper\" [class.current]=\"isCurrent(index + 1)\" [class.completed]=\"isComplete(index + 1)\">\n    <div class=\"step-data\">\n      <div class=\"step-icon\">\n        <div class=\"horizontal-line\" [class.first]=\"isFirst\"></div>\n        <div class=\"icon-container\">\n          <mat-icon *ngIf=\"isComplete(index + 1)\">done</mat-icon>\n          <span *ngIf=\"!isComplete(index + 1)\" class=\"step-index\">{{ index + 1 }}</span>\n        </div>\n        <div class=\"horizontal-line\" [class.last]=\"isLast\"></div>\n      </div>\n      <ng-template\n        [ngTemplateOutlet]=\"step.template\"\n        [ngTemplateOutletContext]=\"{ isCurrent: isCurrent(index + 1) }\"\n      ></ng-template>\n    </div>\n  </div>\n  <div *ngIf=\"!isLast\" class=\"horizontal-line\"></div>\n</ng-container>\n",
                host: { class: 'uxg-horizontal-status-stepper' },
                styles: [".mt-0{margin-top:0!important}.pt-0{padding-top:0!important}.mb-0{margin-bottom:0!important}.pb-0{padding-bottom:0!important}.ml-0{margin-left:0!important}.pl-0{padding-left:0!important}.mr-0{margin-right:0!important}.pr-0{padding-right:0!important}.m-0{margin:0!important}.p-0{padding:0!important}.mt-1{margin-top:4px!important}.pt-1{padding-top:4px!important}.mb-1{margin-bottom:4px!important}.pb-1{padding-bottom:4px!important}.ml-1{margin-left:4px!important}.pl-1{padding-left:4px!important}.mr-1{margin-right:4px!important}.pr-1{padding-right:4px!important}.m-1{margin:4px!important}.p-1{padding:4px!important}.mt-2{margin-top:8px!important}.pt-2{padding-top:8px!important}.mb-2{margin-bottom:8px!important}.pb-2{padding-bottom:8px!important}.ml-2{margin-left:8px!important}.pl-2{padding-left:8px!important}.mr-2{margin-right:8px!important}.pr-2{padding-right:8px!important}.m-2{margin:8px!important}.p-2{padding:8px!important}.mt-3{margin-top:16px!important}.pt-3{padding-top:16px!important}.mb-3{margin-bottom:16px!important}.pb-3{padding-bottom:16px!important}.ml-3{margin-left:16px!important}.pl-3{padding-left:16px!important}.mr-3{margin-right:16px!important}.pr-3{padding-right:16px!important}.m-3{margin:16px!important}.p-3{padding:16px!important}.mt-4{margin-top:24px!important}.pt-4{padding-top:24px!important}.mb-4{margin-bottom:24px!important}.pb-4{padding-bottom:24px!important}.ml-4{margin-left:24px!important}.pl-4{padding-left:24px!important}.mr-4{margin-right:24px!important}.pr-4{padding-right:24px!important}.m-4{margin:24px!important}.p-4{padding:24px!important}.mt-5{margin-top:48px!important}.pt-5{padding-top:48px!important}.mb-5{margin-bottom:48px!important}.pb-5{padding-bottom:48px!important}.ml-5{margin-left:48px!important}.pl-5{padding-left:48px!important}.mr-5{margin-right:48px!important}.pr-5{padding-right:48px!important}.m-5{margin:48px!important}.p-5{padding:48px!important}.mt-6{margin-top:96px!important}.pt-6{padding-top:96px!important}.mb-6{margin-bottom:96px!important}.pb-6{padding-bottom:96px!important}.ml-6{margin-left:96px!important}.pl-6{padding-left:96px!important}.mr-6{margin-right:96px!important}.pr-6{padding-right:96px!important}.m-6{margin:96px!important}.p-6{padding:96px!important}:host{display:flex;width:100%;position:relative}:host .horizontal-stepper{display:flex;justify-content:center;flex:0}:host .step-data{display:flex;flex-direction:column;align-items:center}:host .step-data .step-icon{display:flex;width:100%;margin-bottom:16px}:host .step-data .icon-container{width:32px;height:32px;border-radius:50%;display:flex;align-items:center;justify-content:center;margin:0 10px}:host .step-data .icon-container .mat-icon{font-size:16px;width:16px;height:16px}:host .horizontal-line{flex:1;border-top-width:1px;border-top-style:solid;width:100%;margin-top:16px}:host .horizontal-line.first,:host .horizontal-line.last{border-top-width:0}"]
            },] }
];
/** @nocollapse */
HorizontalStatusStepperComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
HorizontalStatusStepperComponent.propDecorators = {
    steps: [{ type: ContentChildren, args: [StatusStepComponent,] }],
    currentStep: [{ type: Input }]
};

class StatusStepperModule {
}
StatusStepperModule.decorators = [
    { type: NgModule, args: [{
                exports: [HorizontalStatusStepperComponent, StatusStepComponent],
                imports: [CommonModule, MatIconModule],
                declarations: [HorizontalStatusStepperComponent, StatusStepComponent]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { StatusStepperModule, HorizontalStatusStepperComponent as ɵa, StatusStepComponent as ɵb };
//# sourceMappingURL=ffdc-uxg-angular-components-status-steps.js.map
