import { InjectionToken, EventEmitter, Component, Input, Output, HostBinding, HostListener, ViewChildren, Injectable, ComponentFactoryResolver, Inject, ɵɵdefineInjectable, ɵɵinject, NgModule } from '@angular/core';
import { Overlay } from '@angular/cdk/overlay';
import { ComponentPortal } from '@angular/cdk/portal';
import { DOCUMENT, CommonModule } from '@angular/common';
import { style, trigger, transition, animate } from '@angular/animations';
import { FlexLayoutModule } from '@angular/flex-layout';
import { MatIconModule } from '@angular/material/icon';
import { MatButtonModule } from '@angular/material/button';

class Toast {
}
var ToastType;
(function (ToastType) {
    ToastType["SUCCESS"] = "success";
    ToastType["ERROR"] = "error";
    ToastType["WARNING"] = "warning";
    ToastType["INFO"] = "info";
})(ToastType || (ToastType = {}));
var ToastLogicalPosition;
(function (ToastLogicalPosition) {
    ToastLogicalPosition["TOP_START"] = "top-start";
    ToastLogicalPosition["TOP_END"] = "top-end";
    ToastLogicalPosition["BOTTOM_START"] = "bottom-start";
    ToastLogicalPosition["BOTTOM_END"] = "bottom-end";
})(ToastLogicalPosition || (ToastLogicalPosition = {}));
var ToastPhysicalPosition;
(function (ToastPhysicalPosition) {
    ToastPhysicalPosition["TOP_RIGHT"] = "top-right";
    ToastPhysicalPosition["TOP_LEFT"] = "top-left";
    ToastPhysicalPosition["BOTTOM_RIGHT"] = "bottom-right";
    ToastPhysicalPosition["BOTTOM_LEFT"] = "bottom-left";
})(ToastPhysicalPosition || (ToastPhysicalPosition = {}));

const TOASTER_CONFIG = new InjectionToken('Default toaster config');
class ToasterConfig {
    constructor(config) {
        /**
         * Status chooses color scheme for the toast.
         * */
        this.type = 'info';
        /**
         * Duration is timeout between toast appears and disappears. 0 keeps the toast indefinitely on the screen
         * */
        this.duration = 5000;
        /**
         * Determines where on the screen toast have to be rendered.
         * */
        this.position = ToastLogicalPosition.TOP_END;
        /**
         * Destroy by click means you can hide the toast by clicking it.
         * */
        this.destroyByClick = true;
        Object.assign(this, config);
    }
}

class ToasterComponent {
    constructor() {
        this.destroy = new EventEmitter();
    }
    get success() {
        return this.toast.config.type === 'success';
    }
    get info() {
        return this.toast.config.type === 'info';
    }
    get warning() {
        return this.toast.config.type === 'warning';
    }
    get primary() {
        return this.toast.config.type === 'error';
    }
    get destroyByClick() {
        return this.toast.config.destroyByClick;
    }
    onClick() {
        this.destroy.emit();
    }
}
ToasterComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-toaster',
                template: "<div fxLayoutAlign=\"center center\" class=\"icon-container\">\n  <mat-icon dense *ngIf=\"toast.config.type === 'success'\">check_circle_outline</mat-icon>\n  <mat-icon dense *ngIf=\"toast.config.type === 'error'\">error_outline</mat-icon>\n  <mat-icon class=\"material-icons-outlined\" dense *ngIf=\"toast.config.type === 'warning'\">report_problem</mat-icon>\n  <mat-icon class=\"material-icons-outlined\" dense *ngIf=\"toast.config.type === 'info'\">info</mat-icon>\n</div>\n<div fxFlex fxFlexAlign=\"center\" class=\"uxg-body-2 message\">\n  {{ toast.message }}\n</div>\n",
                styles: [".mt-0{margin-top:0!important}.pt-0{padding-top:0!important}.mb-0{margin-bottom:0!important}.pb-0{padding-bottom:0!important}.ml-0{margin-left:0!important}.pl-0{padding-left:0!important}.mr-0{margin-right:0!important}.pr-0{padding-right:0!important}.m-0{margin:0!important}.p-0{padding:0!important}.mt-1{margin-top:4px!important}.pt-1{padding-top:4px!important}.mb-1{margin-bottom:4px!important}.pb-1{padding-bottom:4px!important}.ml-1{margin-left:4px!important}.pl-1{padding-left:4px!important}.mr-1{margin-right:4px!important}.pr-1{padding-right:4px!important}.m-1{margin:4px!important}.p-1{padding:4px!important}.mt-2{margin-top:8px!important}.pt-2{padding-top:8px!important}.mb-2{margin-bottom:8px!important}.pb-2{padding-bottom:8px!important}.ml-2{margin-left:8px!important}.pl-2{padding-left:8px!important}.mr-2{margin-right:8px!important}.pr-2{padding-right:8px!important}.m-2{margin:8px!important}.p-2{padding:8px!important}.mt-3{margin-top:16px!important}.pt-3{padding-top:16px!important}.mb-3{margin-bottom:16px!important}.pb-3{padding-bottom:16px!important}.ml-3{margin-left:16px!important}.pl-3{padding-left:16px!important}.mr-3{margin-right:16px!important}.pr-3{padding-right:16px!important}.m-3{margin:16px!important}.p-3{padding:16px!important}.mt-4{margin-top:24px!important}.pt-4{padding-top:24px!important}.mb-4{margin-bottom:24px!important}.pb-4{padding-bottom:24px!important}.ml-4{margin-left:24px!important}.pl-4{padding-left:24px!important}.mr-4{margin-right:24px!important}.pr-4{padding-right:24px!important}.m-4{margin:24px!important}.p-4{padding:24px!important}.mt-5{margin-top:48px!important}.pt-5{padding-top:48px!important}.mb-5{margin-bottom:48px!important}.pb-5{padding-bottom:48px!important}.ml-5{margin-left:48px!important}.pl-5{padding-left:48px!important}.mr-5{margin-right:48px!important}.pr-5{padding-right:48px!important}.m-5{margin:48px!important}.p-5{padding:48px!important}.mt-6{margin-top:96px!important}.pt-6{padding-top:96px!important}.mb-6{margin-bottom:96px!important}.pb-6{padding-bottom:96px!important}.ml-6{margin-left:96px!important}.pl-6{padding-left:96px!important}.mr-6{margin-right:96px!important}.pr-6{padding-right:96px!important}.m-6{margin:96px!important}.p-6{padding:96px!important}:host{margin:16px 4vw;min-height:48px;width:92vw;border-radius:4px;box-shadow:0 5px 5px -3px rgba(0,0,0,.2),0 8px 10px 1px rgba(0,0,0,.14),0 3px 14px 2px rgba(0,0,0,.12)}:host .icon-container{width:48px;border-radius:4px 0 0 4px;padding:16px}:host .message{padding:16px;word-break:break-word;white-space:pre-line}:host.destroy-by-click{cursor:pointer}@media only screen and (min-width:600px) and (max-width:719px){:host{width:50vw;margin:16px}}@media only screen and (min-width:720px){:host{width:30vw;margin:16px}}"]
            },] }
];
ToasterComponent.propDecorators = {
    toast: [{ type: Input }],
    destroy: [{ type: Output }],
    success: [{ type: HostBinding, args: ['class.type-success',] }],
    info: [{ type: HostBinding, args: ['class.type-info',] }],
    warning: [{ type: HostBinding, args: ['class.type-warning',] }],
    primary: [{ type: HostBinding, args: ['class.type-error',] }],
    destroyByClick: [{ type: HostBinding, args: ['class.destroy-by-click',] }],
    onClick: [{ type: HostListener, args: ['click',] }]
};

const voidState = style({
    transform: 'translateX(110%)',
    height: 0,
    marginLeft: '0',
    marginRight: '0'
});
class ToasterContainerComponent {
    constructor() {
        this.content = [];
    }
    ngOnInit() { }
    ngOnDestroy() { }
}
ToasterContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-toaster-container',
                template: `
    <uxg-toaster
      fxLayout="row"
      fxLayoutAlign="start stretch"
      [@fadeIn]="fadeIn"
      *ngFor="let toast of content"
      [toast]="toast"
    ></uxg-toaster>
  `,
                animations: [
                    trigger('fadeIn', [
                        transition(':enter', [voidState, animate(100)]),
                        transition(':leave', [animate(100, voidState)])
                    ])
                ]
            },] }
];
/** @nocollapse */
ToasterContainerComponent.ctorParameters = () => [];
ToasterContainerComponent.propDecorators = {
    content: [{ type: Input }],
    toasts: [{ type: ViewChildren, args: [ToasterComponent,] }]
};

class ToasterRef {
    constructor(toasterContainer, toast) {
        this.toasterContainer = toasterContainer;
        this.toast = toast;
    }
    close() {
        this.toasterContainer.destroy(this.toast);
    }
}
class ToasterContainerOverlayService {
    constructor(overlay) {
        this.overlay = overlay;
    }
    get scrollStrategies() {
        return this.overlay.scrollStrategies;
    }
    create(config) {
        // Returns an OverlayRef (which is a PortalHost)
        return this.overlay.create(Object.assign(Object.assign({}, config), { panelClass: 'uxg-toaster-overlay' }));
    }
}
ToasterContainerOverlayService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
ToasterContainerOverlayService.ctorParameters = () => [
    { type: Overlay }
];
class ToasterContainer {
    constructor(position, containerRef) {
        this.position = position;
        this.containerRef = containerRef;
        this.toasts = [];
    }
    get nativeElement() {
        return this.containerRef.location.nativeElement;
    }
    attach(toast) {
        const toastComponent = this.attachToast(toast);
        if (toast.config.destroyByClick) {
            this.subscribeOnClick(toastComponent, toast);
        }
        if (toast.config.duration) {
            this.setDestroyTimeout(toast);
        }
        this.prevToast = toast;
        return new ToasterRef(this, toast);
    }
    destroy(toast) {
        if (this.prevToast === toast) {
            this.prevToast = null;
        }
        this.toasts = this.toasts.filter((t) => t !== toast);
        this.updateContainer();
    }
    attachToast(toast) {
        return this.attachToTop(toast);
    }
    attachToTop(toast) {
        this.toasts.unshift(toast);
        this.updateContainer();
        return this.containerRef.instance.toasts.first;
    }
    setDestroyTimeout(toast) {
        setTimeout(() => this.destroy(toast), toast.config.duration);
    }
    subscribeOnClick(toastComponent, toast) {
        toastComponent.destroy.subscribe(() => this.destroy(toast));
    }
    updateContainer() {
        patch(this.containerRef, { content: this.toasts, position: this.position });
    }
}
function patch(container, containerContext) {
    Object.assign(container.instance, containerContext);
    container.changeDetectorRef.detectChanges();
    return container;
}
class ToasterContainerRegistry {
    constructor(overlay, overlayService, cfr, document) {
        this.overlay = overlay;
        this.overlayService = overlayService;
        this.cfr = cfr;
        this.document = document;
        this.overlays = new Map();
    }
    get(position) {
        const logicalPosition = this.toLogicalPosition(position);
        const overlayWithContainer = this.overlays.get(position);
        if (!overlayWithContainer || !this.existsInDom(overlayWithContainer.toasterContainer)) {
            if (overlayWithContainer) {
                overlayWithContainer.overlayRef.dispose();
            }
            this.instantiateContainer(logicalPosition);
        }
        return this.overlays.get(logicalPosition).toasterContainer;
    }
    instantiateContainer(position) {
        const toasterOverlayWithContainer = this.createContainer(position);
        this.overlays.set(position, toasterOverlayWithContainer);
    }
    createContainer(position) {
        const positionStrategy = this.overlay.position().global().top().right(); // TODO - add customizable positioning. hardcoded to top-right for now
        const ref = this.overlayService.create({ positionStrategy });
        ref.hostElement.setAttribute('class', 'uxg-toaster-overlay-wrapper');
        const containerRef = ref.attach(new ComponentPortal(ToasterContainerComponent, null, null, this.cfr));
        return {
            overlayRef: ref,
            toasterContainer: new ToasterContainer(position, containerRef)
        };
    }
    existsInDom(toastContainer) {
        return this.document.body.contains(toastContainer.nativeElement);
    }
    toLogicalPosition(position) {
        if (Object.values(ToastLogicalPosition).includes(position)) {
            return position;
        }
        return ToastLogicalPosition.TOP_START; // TODO - remove when handling positioning
    }
}
ToasterContainerRegistry.decorators = [
    { type: Injectable }
];
/** @nocollapse */
ToasterContainerRegistry.ctorParameters = () => [
    { type: Overlay },
    { type: ToasterContainerOverlayService },
    { type: ComponentFactoryResolver },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];
/**
 * The `ToasterService` provides a capability to build toast notifications.
 *
 * `ToasterService.show(message, config)` accepts two params, config is optional.
 *
 * ### Import
 *
 * Import `ToasterModule` to your app module.
 * ```ts
 * @NgModule({
 *   imports: [
 *     // ...
 *     ToasterModule,
 *   ],
 * })
 * export class AppModule { }
 * ```
 *
 * ### Usage
 *
 * Calling `ToasterService.show(...)` will render new toast and return `ToasterRef` with
 * help of which you may close newly created toast by calling `close` method.
 *
 * ```ts
 * const toastRef: ToasterRef = this.toasterService.show(...);
 * toastRef.close();
 * ```
 *
 * Config accepts following options:
 *
 * `type` - coloring and icon of the toast.
 * Default is `info`.
 *
 * `duration` - the time after which the toast will be destroyed.
 * `0` means endless toast, that may be destroyed by click only.
 * Default is 3000 ms.
 *
 * `position` - determines where on the screen toast will be rendered.
 * Default is `top-end`, hardcoded for now.
 *
 * `destroyByClick` - provides a capability to destroy toast by click.
 * Default is true.
 * */
class ToasterService {
    constructor(globalConfig, containerRegistry) {
        this.globalConfig = globalConfig;
        this.containerRegistry = containerRegistry;
    }
    /**
     * Shows toast with message and user config.
     * */
    show(message, userConfig) {
        const config = new ToasterConfig(Object.assign(Object.assign({}, this.globalConfig), userConfig));
        const container = this.containerRegistry.get(config.position);
        const toast = { message, config };
        return container.attach(toast);
    }
    /**
     * Shows success toast with message, title and user config.
     * */
    success(message, config) {
        return this.show(message, Object.assign(Object.assign({}, config), { type: ToastType.SUCCESS }));
    }
    /**
     * Shows error toast with message, title and user config.
     * */
    error(message, config) {
        return this.show(message, Object.assign(Object.assign({}, config), { type: ToastType.ERROR }));
    }
    /**
     * Shows warning toast with message, title and user config.
     * */
    warning(message, config) {
        return this.show(message, Object.assign(Object.assign({}, config), { type: ToastType.WARNING }));
    }
    /**
     * Shows info toast with message, title and user config.
     * */
    info(message, config) {
        return this.show(message, Object.assign(Object.assign({}, config), { type: ToastType.INFO }));
    }
}
/** @nocollapse */ ToasterService.ɵprov = ɵɵdefineInjectable({ factory: function ToasterService_Factory() { return new ToasterService(ɵɵinject(TOASTER_CONFIG), ɵɵinject(ToasterContainerRegistry)); }, token: ToasterService, providedIn: "root" });
ToasterService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
ToasterService.ctorParameters = () => [
    { type: ToasterConfig, decorators: [{ type: Inject, args: [TOASTER_CONFIG,] }] },
    { type: ToasterContainerRegistry }
];

const ɵ0 = {};
class ToasterModule {
}
ToasterModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, MatIconModule, MatButtonModule, FlexLayoutModule],
                declarations: [ToasterContainerComponent, ToasterComponent],
                providers: [
                    ToasterService,
                    ToasterContainerOverlayService,
                    ToasterContainerRegistry,
                    { provide: TOASTER_CONFIG, useValue: ɵ0 }
                ],
                exports: [ToasterComponent]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { TOASTER_CONFIG, Toast, ToastLogicalPosition, ToastPhysicalPosition, ToastType, ToasterComponent, ToasterConfig, ToasterContainer, ToasterContainerComponent, ToasterContainerOverlayService, ToasterContainerRegistry, ToasterModule, ToasterRef, ToasterService, patch, ɵ0 };
//# sourceMappingURL=ffdc-uxg-angular-components-toaster.js.map
