import { Directive, Component, ViewEncapsulation, ChangeDetectionStrategy, Attribute, Input, ViewChild, TemplateRef, ContentChild, NgModule } from '@angular/core';
import { MatMenuTrigger, MatMenuModule } from '@angular/material/menu';
import { CommonModule } from '@angular/common';
import { MatDividerModule } from '@angular/material/divider';
import { AvatarModule } from '@ffdc/uxg-angular-components/avatar';

class UxgUserProfilePanelActionsDirective {
    constructor() { }
}
UxgUserProfilePanelActionsDirective.decorators = [
    { type: Directive, args: [{ selector: '[uxg-user-profile-panel-actions], [uxgUserProfilePanelActions]' },] }
];
/** @nocollapse */
UxgUserProfilePanelActionsDirective.ctorParameters = () => [];

class UxgUserProfilePanelContentDirective {
    constructor() { }
}
UxgUserProfilePanelContentDirective.decorators = [
    { type: Directive, args: [{ selector: '[uxg-user-profile-panel-content], [uxgUserProfilePanelContent]' },] }
];
/** @nocollapse */
UxgUserProfilePanelContentDirective.ctorParameters = () => [];

class UxgUserProfilePanelDetailsDirective {
    constructor() { }
}
UxgUserProfilePanelDetailsDirective.decorators = [
    { type: Directive, args: [{ selector: '[uxg-user-profile-panel-details], [uxgUserProfilePanelDetails]' },] }
];
/** @nocollapse */
UxgUserProfilePanelDetailsDirective.ctorParameters = () => [];

class UxgUserProfileMenuComponent {
    constructor(dense) {
        this.dense = dense;
        this.color = 'gradient';
        this.headerType = 'title';
    }
}
UxgUserProfileMenuComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-user-profile-menu',
                template: "<uxg-avatar\n  [dense]=\"dense === '' ? true : false\"\n  [color]=\"color\"\n  [name]=\"user.username\"\n  [defaultGravatar]=\"defaultGravatar\"\n  [gravatarEmail]=\"user.gravatarEmail\"\n  [matMenuTriggerFor]=\"menuUserProfile\"\n  [avatarImage]=\"user.photo ? avatarImage : null\"\n>\n</uxg-avatar>\n<mat-menu #menuUserProfile class=\"uxg-user-profile\">\n  <uxg-user-profile-panel\n    [user]=\"user\"\n    [defaultGravatar]=\"defaultGravatar\"\n    [color]=\"color\"\n    [headerType]=\"headerType\"\n    [contentTemplate]=\"uxgUserProfilePanelContent\"\n    [actionsTemplate]=\"uxgUserProfilePanelActions\"\n    [detailsTemplate]=\"uxgUserProfilePanelDetails\"\n  >\n  </uxg-user-profile-panel>\n</mat-menu>\n\n<ng-template #avatarImage>\n  <img [src]=\"user.photo\" />\n</ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush,
                host: {
                    class: 'uxg-user-profile-menu'
                },
                styles: [".uxg-user-profile-menu .uxg-avatar{cursor:pointer}"]
            },] }
];
/** @nocollapse */
UxgUserProfileMenuComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Attribute, args: ['dense',] }] }
];
UxgUserProfileMenuComponent.propDecorators = {
    user: [{ type: Input }],
    defaultGravatar: [{ type: Input }],
    color: [{ type: Input }],
    headerType: [{ type: Input }],
    avatarImage: [{ type: ViewChild, args: ['avatarImage', { read: TemplateRef, static: true },] }],
    userMenuTrigger: [{ type: ViewChild, args: [MatMenuTrigger, { static: true },] }],
    uxgUserProfilePanelContent: [{ type: ContentChild, args: [UxgUserProfilePanelContentDirective, { read: TemplateRef, static: true },] }],
    uxgUserProfilePanelActions: [{ type: ContentChild, args: [UxgUserProfilePanelActionsDirective, { read: TemplateRef, static: true },] }],
    uxgUserProfilePanelDetails: [{ type: ContentChild, args: [UxgUserProfilePanelDetailsDirective, { read: TemplateRef, static: true },] }]
};

class UxgUserProfilePanelComponent {
    constructor() {
        this.color = 'gradient';
        this.headerType = 'title';
        this.hasContent = false;
        this.hasFooter = false;
        this.hasDetails = false;
    }
    ngAfterContentInit() {
        this.hasContent = !!this.uxgUserProfilePanelContent || !!this.contentTemplate;
        this.hasFooter = !!this.uxgUserProfilePanelActions || !!this.actionsTemplate;
        this.hasDetails = !!this.uxgUserProfilePanelDetails || !!this.detailsTemplate;
    }
}
UxgUserProfilePanelComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-user-profile-panel',
                template: "<div class=\"uxg-menu-header\">\n  <div\n    [ngClass]=\"{\n      'uxg-avatar-hero-block': headerType === 'hero',\n      'uxg-avatar-title-block': headerType === 'title'\n    }\"\n  >\n    <uxg-avatar\n      [attr.large]=\"headerType === 'title' ? null : true\"\n      [name]=\"user.username\"\n      [defaultGravatar]=\"defaultGravatar\"\n      [color]=\"color\"\n      [gravatarEmail]=\"user.gravatarEmail\"\n      [avatarImage]=\"user.photo ? avatarImage : null\"\n    >\n    </uxg-avatar>\n    <h6 class=\"uxg-h6\">{{ user.username }}</h6>\n    <div class=\"uxg-caption\">{{ user.email }}</div>\n\n    <ng-container *ngIf=\"hasDetails\">\n      <div>\n        <ng-container *ngTemplateOutlet=\"uxgUserProfilePanelDetails || detailsTemplate\"></ng-container>\n      </div>\n    </ng-container>\n  </div>\n</div>\n\n<ng-container *ngIf=\"hasContent\">\n  <mat-divider></mat-divider>\n  <div>\n    <ng-container *ngTemplateOutlet=\"uxgUserProfilePanelContent || contentTemplate\"></ng-container>\n  </div>\n</ng-container>\n\n<ng-container *ngIf=\"hasFooter\">\n  <mat-divider></mat-divider>\n  <div [ngClass]=\"{ 'uxg-menu-footer': hasFooter }\">\n    <ng-container *ngTemplateOutlet=\"uxgUserProfilePanelActions || actionsTemplate\"></ng-container>\n  </div>\n</ng-container>\n\n<ng-template #avatarImage>\n  <img [src]=\"user.photo\" />\n</ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush,
                host: {
                    class: 'uxg-user-profile-panel',
                    '[class.has-content]': 'hasContent'
                }
            },] }
];
/** @nocollapse */
UxgUserProfilePanelComponent.ctorParameters = () => [];
UxgUserProfilePanelComponent.propDecorators = {
    user: [{ type: Input }],
    defaultGravatar: [{ type: Input }],
    color: [{ type: Input }],
    headerType: [{ type: Input }],
    contentTemplate: [{ type: Input }],
    actionsTemplate: [{ type: Input }],
    detailsTemplate: [{ type: Input }],
    avatarImage: [{ type: ViewChild, args: ['avatarImage', { read: TemplateRef, static: true },] }],
    uxgUserProfilePanelContent: [{ type: ContentChild, args: [UxgUserProfilePanelContentDirective, { read: TemplateRef, static: true },] }],
    uxgUserProfilePanelActions: [{ type: ContentChild, args: [UxgUserProfilePanelActionsDirective, { read: TemplateRef, static: true },] }],
    uxgUserProfilePanelDetails: [{ type: ContentChild, args: [UxgUserProfilePanelDetailsDirective, { read: TemplateRef, static: true },] }]
};

class UxgUserProfileMenuModule {
}
UxgUserProfileMenuModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, AvatarModule, MatDividerModule, MatMenuModule],
                exports: [
                    UxgUserProfileMenuComponent,
                    UxgUserProfilePanelComponent,
                    UxgUserProfilePanelActionsDirective,
                    UxgUserProfilePanelContentDirective,
                    UxgUserProfilePanelDetailsDirective
                ],
                declarations: [
                    UxgUserProfilePanelComponent,
                    UxgUserProfileMenuComponent,
                    UxgUserProfilePanelActionsDirective,
                    UxgUserProfilePanelContentDirective,
                    UxgUserProfilePanelDetailsDirective
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { UxgUserProfileMenuComponent, UxgUserProfileMenuModule, UxgUserProfilePanelActionsDirective, UxgUserProfilePanelComponent, UxgUserProfilePanelContentDirective, UxgUserProfilePanelDetailsDirective };
//# sourceMappingURL=ffdc-uxg-angular-components-user-profile-menu.js.map
