import { EventEmitter, Component, ViewChild, Input, Output, HostListener, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { MatTooltipModule } from '@angular/material/tooltip';
import { FlexLayoutModule } from '@angular/flex-layout';
import { MatInputModule } from '@angular/material/input';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatSelectModule } from '@angular/material/select';
import { PALETTE_DEFAULT_CONFIG, PaletteService, LazyloadScriptService } from '@ffdc/uxg-angular-components/core';
import { PlotComponent, PlotlyService, PlotlyViaCDNModule } from 'angular-plotly.js';

const COUNTRIES = [
    { name: 'Afghanistan', value: 0, code: 'AFG' },
    { name: 'Albania', value: 0, code: 'ALB' },
    { name: 'Algeria', value: 0, code: 'DZA' },
    { name: 'American Samoa', value: 0, code: 'ASM' },
    { name: 'Andorra', value: 0, code: 'AND' },
    { name: 'Angola', value: 0, code: 'AGO' },
    { name: 'Anguilla', value: 0, code: 'AIA' },
    { name: 'Antigua and Barbuda', value: 0, code: 'ATG' },
    { name: 'Argentina', value: 0, code: 'ARG' },
    { name: 'Armenia', value: 0, code: 'ARM' },
    { name: 'Aruba', value: 0, code: 'ABW' },
    { name: 'Australia', value: 0, code: 'AUS' },
    { name: 'Austria', value: 0, code: 'AUT' },
    { name: 'Azerbaijan', value: 0, code: 'AZE' },
    { name: 'Bahamas, The', value: 0, code: 'BHM' },
    { name: 'Bahrain', value: 0, code: 'BHR' },
    { name: 'Bangladesh', value: 0, code: 'BGD' },
    { name: 'Barbados', value: 0, code: 'BRB' },
    { name: 'Belarus', value: 0, code: 'BLR' },
    { name: 'Belgium', value: 0, code: 'BEL' },
    { name: 'Belize', value: 0, code: 'BLZ' },
    { name: 'Benin', value: 0, code: 'BEN' },
    { name: 'Bermuda', value: 0, code: 'BMU' },
    { name: 'Bhutan', value: 0, code: 'BTN' },
    { name: 'Bolivia', value: 0, code: 'BOL' },
    { name: 'Bosnia and Herzegovina', value: 0, code: 'BIH' },
    { name: 'Botswana', value: 0, code: 'BWA' },
    { name: 'Brazil', value: 0, code: 'BRA' },
    { name: 'British Virgin Islands', value: 0, code: 'VGB' },
    { name: 'Brunei', value: 0, code: 'BRN' },
    { name: 'Bulgaria', value: 0, code: 'BGR' },
    { name: 'Burkina Faso', value: 0, code: 'BFA' },
    { name: 'Burma', value: 0, code: 'MMR' },
    { name: 'Burundi', value: 0, code: 'BDI' },
    { name: 'Cabo Verde', value: 0, code: 'CPV' },
    { name: 'Cambodia', value: 0, code: 'KHM' },
    { name: 'Cameroon', value: 0, code: 'CMR' },
    { name: 'Canada', value: 0, code: 'CAN' },
    { name: 'Cayman Islands', value: 0, code: 'CYM' },
    { name: 'Central African Republic', value: 0, code: 'CAF' },
    { name: 'Chad', value: 0, code: 'TCD' },
    { name: 'Chile', value: 0, code: 'CHL' },
    { name: 'China', value: 0, code: 'CHN' },
    { name: 'Colombia', value: 0, code: 'COL' },
    { name: 'Comoros', value: 0, code: 'COM' },
    { name: 'Congo, Democratic Republic of the', value: 0, code: 'COD' },
    { name: 'Congo, Republic of the', value: 0, code: 'COG' },
    { name: 'Cook Islands', value: 0, code: 'COK' },
    { name: 'Costa Rica', value: 0, code: 'CRI' },
    { name: "Cote d'Ivoire", value: 0, code: 'CIV' },
    { name: 'Croatia', value: 0, code: 'HRV' },
    { name: 'Cuba', value: 0, code: 'CUB' },
    { name: 'Curacao', value: 0, code: 'CUW' },
    { name: 'Cyprus', value: 0, code: 'CYP' },
    { name: 'Czech Republic', value: 0, code: 'CZE' },
    { name: 'Denmark', value: 0, code: 'DNK' },
    { name: 'Djibouti', value: 0, code: 'DJI' },
    { name: 'Dominica', value: 0, code: 'DMA' },
    { name: 'Dominican Republic', value: 0, code: 'DOM' },
    { name: 'Ecuador', value: 0, code: 'ECU' },
    { name: 'Egypt', value: 0, code: 'EGY' },
    { name: 'El Salvador', value: 0, code: 'SLV' },
    { name: 'Equatorial Guinea', value: 0, code: 'GNQ' },
    { name: 'Eritrea', value: 0, code: 'ERI' },
    { name: 'Estonia', value: 0, code: 'EST' },
    { name: 'Ethiopia', value: 0, code: 'ETH' },
    { name: 'Falkland Islands (Islas Malvinas)', value: 0, code: 'FLK' },
    { name: 'Faroe Islands', value: 0, code: 'FRO' },
    { name: 'Fiji', value: 0, code: 'FJI' },
    { name: 'Finland', value: 0, code: 'FIN' },
    { name: 'France', value: 0, code: 'FRA' },
    { name: 'French Polynesia', value: 0, code: 'PYF' },
    { name: 'Gabon', value: 0, code: 'GAB' },
    { name: 'Gambia, The', value: 0, code: 'GMB' },
    { name: 'Georgia', value: 0, code: 'GEO' },
    { name: 'Germany', value: 0, code: 'DEU' },
    { name: 'Ghana', value: 0, code: 'GHA' },
    { name: 'Gibraltar', value: 0, code: 'GIB' },
    { name: 'Greece', value: 0, code: 'GRC' },
    { name: 'Greenland', value: 0, code: 'GRL' },
    { name: 'Grenada', value: 0, code: 'GRD' },
    { name: 'Guam', value: 0, code: 'GUM' },
    { name: 'Guatemala', value: 0, code: 'GTM' },
    { name: 'Guernsey', value: 0, code: 'GGY' },
    { name: 'Guinea-Bissau', value: 0, code: 'GNB' },
    { name: 'Guinea', value: 0, code: 'GIN' },
    { name: 'Guyana', value: 0, code: 'GUY' },
    { name: 'Haiti', value: 0, code: 'HTI' },
    { name: 'Honduras', value: 0, code: 'HND' },
    { name: 'Hong Kong', value: 0, code: 'HKG' },
    { name: 'Hungary', value: 0, code: 'HUN' },
    { name: 'Iceland', value: 0, code: 'ISL' },
    { name: 'India', value: 0, code: 'IND' },
    { name: 'Indonesia', value: 0, code: 'IDN' },
    { name: 'Iran', value: 0, code: 'IRN' },
    { name: 'Iraq', value: 0, code: 'IRQ' },
    { name: 'Ireland', value: 0, code: 'IRL' },
    { name: 'Isle of Man', value: 0, code: 'IMN' },
    { name: 'Israel', value: 0, code: 'ISR' },
    { name: 'Italy', value: 0, code: 'ITA' },
    { name: 'Jamaica', value: 0, code: 'JAM' },
    { name: 'Japan', value: 0, code: 'JPN' },
    { name: 'Jersey', value: 0, code: 'JEY' },
    { name: 'Jordan', value: 0, code: 'JOR' },
    { name: 'Kazakhstan', value: 0, code: 'KAZ' },
    { name: 'Kenya', value: 0, code: 'KEN' },
    { name: 'Kiribati', value: 0, code: 'KIR' },
    { name: 'Korea, North', value: 0, code: 'PRK' },
    { name: 'Korea, South', value: 0, code: 'KOR' },
    { name: 'Kosovo', value: 0, code: 'KSV' },
    { name: 'Kuwait', value: 0, code: 'KWT' },
    { name: 'Kyrgyzstan', value: 0, code: 'KGZ' },
    { name: 'Laos', value: 0, code: 'LAO' },
    { name: 'Latvia', value: 0, code: 'LVA' },
    { name: 'Lebanon', value: 0, code: 'LBN' },
    { name: 'Lesotho', value: 0, code: 'LSO' },
    { name: 'Liberia', value: 0, code: 'LBR' },
    { name: 'Libya', value: 0, code: 'LBY' },
    { name: 'Liechtenstein', value: 0, code: 'LIE' },
    { name: 'Lithuania', value: 0, code: 'LTU' },
    { name: 'Luxembourg', value: 0, code: 'LUX' },
    { name: 'Macau', value: 0, code: 'MAC' },
    { name: 'Macedonia', value: 0, code: 'MKD' },
    { name: 'Madagascar', value: 0, code: 'MDG' },
    { name: 'Malawi', value: 0, code: 'MWI' },
    { name: 'Malaysia', value: 0, code: 'MYS' },
    { name: 'Maldives', value: 0, code: 'MDV' },
    { name: 'Mali', value: 0, code: 'MLI' },
    { name: 'Malta', value: 0, code: 'MLT' },
    { name: 'Marshall Islands', value: 0, code: 'MHL' },
    { name: 'Mauritania', value: 0, code: 'MRT' },
    { name: 'Mauritius', value: 0, code: 'MUS' },
    { name: 'Mexico', value: 0, code: 'MEX' },
    { name: 'Micronesia, Federated States of', value: 0, code: 'FSM' },
    { name: 'Moldova', value: 0, code: 'MDA' },
    { name: 'Monaco', value: 0, code: 'MCO' },
    { name: 'Mongolia', value: 0, code: 'MNG' },
    { name: 'Montenegro', value: 0, code: 'MNE' },
    { name: 'Morocco', value: 0, code: 'MAR' },
    { name: 'Mozambique', value: 0, code: 'MOZ' },
    { name: 'Namibia', value: 0, code: 'NAM' },
    { name: 'Nepal', value: 0, code: 'NPL' },
    { name: 'Netherlands', value: 0, code: 'NLD' },
    { name: 'New Caledonia', value: 0, code: 'NCL' },
    { name: 'New Zealand', value: 0, code: 'NZL' },
    { name: 'Nicaragua', value: 0, code: 'NIC' },
    { name: 'Nigeria', value: 0, code: 'NGA' },
    { name: 'Niger', value: 0, code: 'NER' },
    { name: 'Niue', value: 0, code: 'NIU' },
    { name: 'Northern Mariana Islands', value: 0, code: 'MNP' },
    { name: 'Norway', value: 0, code: 'NOR' },
    { name: 'Oman', value: 0, code: 'OMN' },
    { name: 'Pakistan', value: 0, code: 'PAK' },
    { name: 'Palau', value: 0, code: 'PLW' },
    { name: 'Panama', value: 0, code: 'PAN' },
    { name: 'Papua New Guinea', value: 0, code: 'PNG' },
    { name: 'Paraguay', value: 0, code: 'PRY' },
    { name: 'Peru', value: 0, code: 'PER' },
    { name: 'Philippines', value: 0, code: 'PHL' },
    { name: 'Poland', value: 0, code: 'POL' },
    { name: 'Portugal', value: 0, code: 'PRT' },
    { name: 'Puerto Rico', value: 0, code: 'PRI' },
    { name: 'Qatar', value: 0, code: 'QAT' },
    { name: 'Romania', value: 0, code: 'ROU' },
    { name: 'Russia', value: 0, code: 'RUS' },
    { name: 'Rwanda', value: 0, code: 'RWA' },
    { name: 'Saint Kitts and Nevis', value: 0, code: 'KNA' },
    { name: 'Saint Lucia', value: 0, code: 'LCA' },
    { name: 'Saint Martin', value: 0, code: 'MAF' },
    { name: 'Saint Pierre and Miquelon', value: 0, code: 'SPM' },
    { name: 'Saint Vincent and the Grenadines', value: 0, code: 'VCT' },
    { name: 'Samoa', value: 0, code: 'WSM' },
    { name: 'San Marino', value: 0, code: 'SMR' },
    { name: 'Sao Tome and Principe', value: 0, code: 'STP' },
    { name: 'Saudi Arabia', value: 0, code: 'SAU' },
    { name: 'Senegal', value: 0, code: 'SEN' },
    { name: 'Serbia', value: 0, code: 'SRB' },
    { name: 'Seychelles', value: 0, code: 'SYC' },
    { name: 'Sierra Leone', value: 0, code: 'SLE' },
    { name: 'Singapore', value: 0, code: 'SGP' },
    { name: 'Sint Maarten', value: 0, code: 'SXM' },
    { name: 'Slovakia', value: 0, code: 'SVK' },
    { name: 'Slovenia', value: 0, code: 'SVN' },
    { name: 'Solomon Islands', value: 0, code: 'SLB' },
    { name: 'Somalia', value: 0, code: 'SOM' },
    { name: 'South Africa', value: 0, code: 'ZAF' },
    { name: 'South Sudan', value: 0, code: 'SSD' },
    { name: 'Spain', value: 0, code: 'ESP' },
    { name: 'Sri Lanka', value: 0, code: 'LKA' },
    { name: 'Sudan', value: 0, code: 'SDN' },
    { name: 'Suriname', value: 0, code: 'SUR' },
    { name: 'Swaziland', value: 0, code: 'SWZ' },
    { name: 'Sweden', value: 0, code: 'SWE' },
    { name: 'Switzerland', value: 0, code: 'CHE' },
    { name: 'Syria', value: 0, code: 'SYR' },
    { name: 'Taiwan', value: 0, code: 'TWN' },
    { name: 'Tajikistan', value: 0, code: 'TJK' },
    { name: 'Tanzania', value: 0, code: 'TZA' },
    { name: 'Thailand', value: 0, code: 'THA' },
    { name: 'Timor-Leste', value: 0, code: 'TLS' },
    { name: 'Togo', value: 0, code: 'TGO' },
    { name: 'Tonga', value: 0, code: 'TON' },
    { name: 'Trinidad and Tobago', value: 0, code: 'TTO' },
    { name: 'Tunisia', value: 0, code: 'TUN' },
    { name: 'Turkey', value: 0, code: 'TUR' },
    { name: 'Turkmenistan', value: 0, code: 'TKM' },
    { name: 'Tuvalu', value: 0, code: 'TUV' },
    { name: 'Uganda', value: 0, code: 'UGA' },
    { name: 'Ukraine', value: 0, code: 'UKR' },
    { name: 'United Arab Emirates', value: 0, code: 'ARE' },
    { name: 'United Kingdom', value: 0, code: 'GBR' },
    { name: 'United States', value: 0, code: 'USA' },
    { name: 'Uruguay', value: 0, code: 'URY' },
    { name: 'Uzbekistan', value: 0, code: 'UZB' },
    { name: 'Vanuatu', value: 0, code: 'VUT' },
    { name: 'Venezuela', value: 0, code: 'VEN' },
    { name: 'Vietnam', value: 0, code: 'VNM' },
    { name: 'Virgin Islands', value: 0, code: 'VGB' },
    { name: 'West Bank', value: 0, code: 'WBG' },
    { name: 'Yemen', value: 0, code: 'YEM' },
    { name: 'Zambia', value: 0, code: 'ZMB' },
    { name: 'Zimbabwe', value: 0, code: 'ZWE' }
];
const DEFAULT_DATA = {
    type: 'choropleth',
    hoverinfo: 'none',
    autocolorscale: false,
    reversescale: true,
    marker: {
        line: {}
    },
    tick0: 0,
    zmin: 0,
    zmax: 1,
    showscale: false
};
const DEFAULT_LAYOUT = {
    autosize: true,
    geo: {
        showframe: false,
        showcoastlines: false,
        projection: {
            type: 'miller'
        },
        center: {
            lat: 25,
            lon: 0
        }
    },
    margin: {
        l: 0,
        r: 0,
        b: 0,
        t: 0,
        pad: 0
    }
};
const DEFAULT_CONFIG = {
    displayModeBar: false,
    responsive: true
};
const DEFAULT_STYLE = {
    position: 'relative',
    width: '100%',
    height: '100%'
};

class VectorMapComponent {
    constructor(paletteService, lazyLoadScriptService) {
        this.paletteService = paletteService;
        this.lazyLoadScriptService = lazyLoadScriptService;
        this.title = 'Vector Map';
        this.dataSource = [];
        this.showLegend = true;
        this.autoResize = true;
        // tslint:disable-next-line: no-output-native
        this.click = new EventEmitter();
        this.viewChange = new EventEmitter();
        this.countries = [];
        this.data = [];
        this.layout = {};
        this.config = {};
        this.style = {};
        this.paletteConfig = PALETTE_DEFAULT_CONFIG;
        this.legend = [];
        this.viewId = null;
        this.views = [];
        this.tooltipTop = '';
        this.tooltipLeft = '0px';
        this.max = 1;
        this.subscriptions = [];
        this.click = new EventEmitter();
        this.plotlyReady$ = lazyLoadScriptService.load('plotly.js', 'Plotly');
    }
    ngOnInit() {
        this.setView();
        this.setLayout();
        this.setConfig();
        this.setStyle();
        this.subscriptions.push(this.paletteService.paletteChange$.subscribe((config) => {
            this.paletteConfig = config;
            this.setPlotData();
            if (this.plot)
                this.refresh();
        }));
    }
    ngOnChanges({ dataSource, showLegend }) {
        let refreshPlot = false;
        let timedOutRefreshPlot = false;
        if (dataSource && !dataSource.isFirstChange()) {
            this.setView();
            this.setLayout();
            this.setPlotData();
            if (this.showLegend)
                timedOutRefreshPlot = true;
        }
        if (showLegend && !showLegend.isFirstChange() && showLegend.currentValue !== showLegend.previousValue) {
            timedOutRefreshPlot = true;
        }
        if (timedOutRefreshPlot) {
            // passing check for next pass in browser event loop / angular lifecycle
            // checks so that the legend is hidden / shown properly
            setTimeout(() => {
                this.refresh();
            });
            refreshPlot = false;
        }
        if (refreshPlot) {
            this.refresh();
        }
    }
    ngOnDestroy() {
        this.subscriptions.forEach((subscription) => subscription.unsubscribe());
    }
    onWindowResize() {
        if (this.autoResize) {
            this.refresh();
        }
    }
    refresh() {
        try {
            this.plot.revision++;
            this.plot.updatePlot();
        }
        catch (_a) {
            this.plot.revision--;
        }
    }
    getLegendValue(value, max) {
        return Math.floor(parseFloat((1 - value).toString()) * max);
    }
    getData() {
        return this.dataSource instanceof Array ? this.dataSource : this.viewId ? this.dataSource.data[this.viewId] : [];
    }
    setLayout(layout = {}) {
        this.layout = Object.assign(Object.assign({}, DEFAULT_LAYOUT), layout);
    }
    setConfig(config = {}) {
        this.config = Object.assign(Object.assign({}, DEFAULT_CONFIG), config);
    }
    setStyle(style = {}) {
        this.style = Object.assign(Object.assign({}, DEFAULT_STYLE), style);
    }
    setView() {
        this.viewId = this.dataSource instanceof Array ? null : this.dataSource.views[0].id;
        if (this.viewId) {
            this.viewChange = this.viewChange || new EventEmitter();
            this.views = this.dataSource.views;
        }
        else {
            this.views = null;
        }
    }
    setPlotData() {
        const data = this.getData();
        this.max = Math.max(...[0, ...data.map(({ value }) => value)]);
        this.setCountries(data);
        this.setLegend(this.paletteConfig.colorScale);
        this.data = [
            Object.assign(Object.assign({}, DEFAULT_DATA), { locations: this.countries.map(({ code }) => code), z: this.countries.map(({ value }) => value), text: this.countries.map(({ name }) => name), colorscale: this.paletteConfig.colorScale, marker: {
                    line: {
                        color: this.paletteConfig.vectorMap.marker.line.color,
                        width: this.paletteConfig.vectorMap.marker.line.width
                    }
                }, zmax: this.max ? this.max : 1 })
        ];
    }
    setCountries(data) {
        this.countries = COUNTRIES.map((country) => {
            const countryData = data.find(({ name, code }) => name === country.name || code === country.code) || country;
            return Object.assign(Object.assign({}, country), { value: countryData ? countryData.value || 0 : 0 });
        });
    }
    setLegend(colorScale) {
        this.legend.length = 0;
        colorScale.forEach((color, i, arr) => {
            if (i === 0)
                return;
            let text, v, v1, v2;
            switch (color[0]) {
                case 0.1:
                    v = this.getLegendValue(color[0], this.max);
                    text = `>= ${v}`;
                    break;
                case 1:
                    v = this.getLegendValue(arr[i - 1][0], this.max);
                    text = `< ${v}`;
                    break;
                default:
                    v1 = this.getLegendValue(color[0], this.max);
                    v2 = this.getLegendValue(arr[i - 1][0], this.max) - 1;
                    text = `${v1} — ${v2}`;
            }
            this.legend.push({
                color: color[1].toString(),
                text: text
            });
        });
    }
    onHover({ points: [point] }) {
        const box = document.querySelectorAll('.choroplethlocation')[point.pointIndex].getBBox();
        this.tooltipLeft = box.x + this.plot.plotEl.nativeElement.offsetLeft + box.width / 2 + 'px';
        this.tooltipTop = box.y + this.plot.plotEl.nativeElement.offsetTop + box.height / 2 + 'px';
        this.tooltip.message = `${point.text}: ${point.z}`;
        this.tooltip.show(200);
    }
    onUnHover() {
        this.tooltip.hide(200);
    }
    onPlotClick({ points: [point] }) {
        const clickedCountry = this.countries[point.pointIndex];
        this.click.emit(this.getData().find(({ name, code }) => name === clickedCountry.name || code === clickedCountry.code));
    }
    onViewChange($event) {
        this.viewId = $event.value;
        this.setPlotData();
        this.plot.revision++;
        this.viewChange.emit(this.dataSource.views[$event.value]);
    }
}
VectorMapComponent.decorators = [
    { type: Component, args: [{
                selector: 'uxg-vector-map',
                template: "<div class=\"vector-map\" fxLayout=\"column\">\n  <h3 class=\"uxg-h3\">{{ title }}</h3>\n  <div fxFlex=\"fill\" class=\"wrapper\" fxLayout=\"row\" fxLayout.xs=\"column\" #wrapper>\n    <div class=\"map\" fxFlex=\"fill\" #map>\n      <plotly-plot\n        *ngIf=\"plotlyReady$ | async\"\n        [data]=\"data\"\n        [layout]=\"layout\"\n        [config]=\"config\"\n        [style]=\"style\"\n        [useResizeHandler]=\"true\"\n        (hover)=\"onHover($event)\"\n        (unhover)=\"onUnHover()\"\n        (plotly_click)=\"onPlotClick($event)\"\n      >\n      </plotly-plot>\n    </div>\n    <div class=\"meta\" *ngIf=\"views || (max > 0 && showLegend === true)\">\n      <div class=\"meta-wrapper\" fxLayout=\"column\" fxLayoutAlign=\"center space-between\">\n        <div class=\"views\" *ngIf=\"views\">\n          <mat-form-field>\n            <mat-label>View by</mat-label>\n            <mat-select (selectionChange)=\"onViewChange($event)\" [value]=\"views[0]?.id\">\n              <mat-option *ngFor=\"let view of views\" [value]=\"view.id\">\n                {{ view.text }}\n              </mat-option>\n            </mat-select>\n          </mat-form-field>\n        </div>\n        <div class=\"legend\" *ngIf=\"max > 0 && showLegend === true\">\n          <ol>\n            <li *ngFor=\"let item of legend\">\n              <span class=\"color\" [ngStyle]=\"{ background: item.color }\"></span>\n              <span class=\"text uxg-body-3\">{{ item.text }}</span>\n            </li>\n          </ol>\n        </div>\n      </div>\n    </div>\n  </div>\n  <div\n    class=\"tooltip-parent\"\n    [ngStyle]=\"{ top: tooltipTop, left: tooltipLeft }\"\n    #tooltip=\"matTooltip\"\n    matTooltip=\"Text\"\n    matTooltipPosition=\"above\"\n  ></div>\n</div>\n",
                styles: [".mt-0{margin-top:0!important}.pt-0{padding-top:0!important}.mb-0{margin-bottom:0!important}.pb-0{padding-bottom:0!important}.ml-0{margin-left:0!important}.pl-0{padding-left:0!important}.mr-0{margin-right:0!important}.pr-0{padding-right:0!important}.m-0{margin:0!important}.p-0{padding:0!important}.mt-1{margin-top:4px!important}.pt-1{padding-top:4px!important}.mb-1{margin-bottom:4px!important}.pb-1{padding-bottom:4px!important}.ml-1{margin-left:4px!important}.pl-1{padding-left:4px!important}.mr-1{margin-right:4px!important}.pr-1{padding-right:4px!important}.m-1{margin:4px!important}.p-1{padding:4px!important}.mt-2{margin-top:8px!important}.pt-2{padding-top:8px!important}.mb-2{margin-bottom:8px!important}.pb-2{padding-bottom:8px!important}.ml-2{margin-left:8px!important}.pl-2{padding-left:8px!important}.mr-2{margin-right:8px!important}.pr-2{padding-right:8px!important}.m-2{margin:8px!important}.p-2{padding:8px!important}.mt-3{margin-top:16px!important}.pt-3{padding-top:16px!important}.mb-3{margin-bottom:16px!important}.pb-3{padding-bottom:16px!important}.ml-3{margin-left:16px!important}.pl-3{padding-left:16px!important}.mr-3{margin-right:16px!important}.pr-3{padding-right:16px!important}.m-3{margin:16px!important}.p-3{padding:16px!important}.mt-4{margin-top:24px!important}.pt-4{padding-top:24px!important}.mb-4{margin-bottom:24px!important}.pb-4{padding-bottom:24px!important}.ml-4{margin-left:24px!important}.pl-4{padding-left:24px!important}.mr-4{margin-right:24px!important}.pr-4{padding-right:24px!important}.m-4{margin:24px!important}.p-4{padding:24px!important}.mt-5{margin-top:48px!important}.pt-5{padding-top:48px!important}.mb-5{margin-bottom:48px!important}.pb-5{padding-bottom:48px!important}.ml-5{margin-left:48px!important}.pl-5{padding-left:48px!important}.mr-5{margin-right:48px!important}.pr-5{padding-right:48px!important}.m-5{margin:48px!important}.p-5{padding:48px!important}.mt-6{margin-top:96px!important}.pt-6{padding-top:96px!important}.mb-6{margin-bottom:96px!important}.pb-6{padding-bottom:96px!important}.ml-6{margin-left:96px!important}.pl-6{padding-left:96px!important}.mr-6{margin-right:96px!important}.pr-6{padding-right:96px!important}.m-6{margin:96px!important}.p-6{padding:96px!important}.vector-map{display:block;position:relative;height:100%;padding:16px}.map,.wrapper{height:100%}.meta-wrapper{display:inline-block;padding-left:16px;height:100%}.legend{margin-top:auto;margin-left:auto}.legend li,.legend ol{margin:0;padding:0}.legend ol{list-style:none}.legend li{position:relative;white-space:nowrap;display:flex}@media only screen and (max-width:599px){.legend li{display:inline-flex;margin-right:16px}}.legend .color{border-radius:50%;display:inline-block;width:10px;height:10px;margin-top:4px}.legend .text{display:inline-block;margin-left:8px}.tooltip-parent{position:absolute}"]
            },] }
];
/** @nocollapse */
VectorMapComponent.ctorParameters = () => [
    { type: PaletteService },
    { type: LazyloadScriptService }
];
VectorMapComponent.propDecorators = {
    plot: [{ type: ViewChild, args: [PlotComponent, { static: false },] }],
    tooltip: [{ type: ViewChild, args: ['tooltip', { static: true },] }],
    title: [{ type: Input }],
    dataSource: [{ type: Input }],
    showLegend: [{ type: Input }],
    autoResize: [{ type: Input }],
    click: [{ type: Output }],
    viewChange: [{ type: Output }],
    onWindowResize: [{ type: HostListener, args: ['window:resize',] }]
};

class VectorMapModule {
    constructor(lazyLoadScriptService) {
        lazyLoadScriptService.load('plotly.js', 'Plotly').subscribe((plotly) => {
            PlotlyService.setPlotly(plotly);
        });
    }
}
VectorMapModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    MatTooltipModule,
                    FlexLayoutModule,
                    MatSelectModule,
                    MatFormFieldModule,
                    MatInputModule,
                    PlotlyViaCDNModule
                ],
                declarations: [VectorMapComponent],
                exports: [VectorMapComponent]
            },] }
];
/** @nocollapse */
VectorMapModule.ctorParameters = () => [
    { type: LazyloadScriptService }
];

/**
 * Generated bundle index. Do not edit.
 */

export { COUNTRIES, DEFAULT_CONFIG, DEFAULT_DATA, DEFAULT_LAYOUT, DEFAULT_STYLE, VectorMapComponent, VectorMapModule };
//# sourceMappingURL=ffdc-uxg-angular-components-vector-map.js.map
